from nsexceptions import NSNitroError
from nsexceptions import NSNitroExceptionClassMap
from nsexceptions import NSNitroNserrNotrunning
from nsexceptions import NSNitroNserrPerm
from nsexceptions import NSNitroNserrNoent
from nsexceptions import NSNitroNserrSrch
from nsexceptions import NSNitroNserrIntr
from nsexceptions import NSNitroNserrIo
from nsexceptions import NSNitroNserrNxio
from nsexceptions import NSNitroNserr2big
from nsexceptions import NSNitroNserrNoexec
from nsexceptions import NSNitroNserrBadf
from nsexceptions import NSNitroNserrChild
from nsexceptions import NSNitroNserrDeadlk
from nsexceptions import NSNitroNserrNomem
from nsexceptions import NSNitroNserrAcces
from nsexceptions import NSNitroNserrFault
from nsexceptions import NSNitroNserrNotblk
from nsexceptions import NSNitroNserrBusy
from nsexceptions import NSNitroNserrExist
from nsexceptions import NSNitroNserrXdev
from nsexceptions import NSNitroNserrNodev
from nsexceptions import NSNitroNserrNotdir
from nsexceptions import NSNitroNserrIsdir
from nsexceptions import NSNitroNserrInval
from nsexceptions import NSNitroNserrNfile
from nsexceptions import NSNitroNserrMfile
from nsexceptions import NSNitroNserrNotty
from nsexceptions import NSNitroNserrTxtbsy
from nsexceptions import NSNitroNserrFbig
from nsexceptions import NSNitroNserrNospace
from nsexceptions import NSNitroNserrSpipe
from nsexceptions import NSNitroNserrRofs
from nsexceptions import NSNitroNserrMlink
from nsexceptions import NSNitroNserrPipe
from nsexceptions import NSNitroNserrDom
from nsexceptions import NSNitroNserrRange
from nsexceptions import NSNitroNserrAgain
from nsexceptions import NSNitroNserrInprogress
from nsexceptions import NSNitroNserrAlready
from nsexceptions import NSNitroNserrNotsock
from nsexceptions import NSNitroNserrDestaddrreq
from nsexceptions import NSNitroNserrMsgsize
from nsexceptions import NSNitroNserrPrototype
from nsexceptions import NSNitroNserrNoprotoopt
from nsexceptions import NSNitroNserrProtonosupport
from nsexceptions import NSNitroNserrSocktnosupport
from nsexceptions import NSNitroNserrOpnotsupp
from nsexceptions import NSNitroNserrPfnosupport
from nsexceptions import NSNitroNserrAfnosupport
from nsexceptions import NSNitroNserrAddrinuse
from nsexceptions import NSNitroNserrAddrnotavail
from nsexceptions import NSNitroNserrNetdown
from nsexceptions import NSNitroNserrNetunreach
from nsexceptions import NSNitroNserrNetreset
from nsexceptions import NSNitroNserrConnaborted
from nsexceptions import NSNitroNserrConnreset
from nsexceptions import NSNitroNserrNobufs
from nsexceptions import NSNitroNserrIsconn
from nsexceptions import NSNitroNserrNotconn
from nsexceptions import NSNitroNserrShutdown
from nsexceptions import NSNitroNserrToomanyrefs
from nsexceptions import NSNitroNserrTimedout
from nsexceptions import NSNitroNserrConnrefused
from nsexceptions import NSNitroNserrLoop
from nsexceptions import NSNitroNserrNametoolong
from nsexceptions import NSNitroNserrHostdown
from nsexceptions import NSNitroNserrHostunreach
from nsexceptions import NSNitroNserrNotempty
from nsexceptions import NSNitroNserrProclim
from nsexceptions import NSNitroNserrUsers
from nsexceptions import NSNitroNserrDquot
from nsexceptions import NSNitroNserrStale
from nsexceptions import NSNitroNserrRemote
from nsexceptions import NSNitroNserrBadrpc
from nsexceptions import NSNitroNserrRpcmismatch
from nsexceptions import NSNitroNserrProgunavail
from nsexceptions import NSNitroNserrProgmismatch
from nsexceptions import NSNitroNserrProcunavail
from nsexceptions import NSNitroNserrNolck
from nsexceptions import NSNitroNserrNosys
from nsexceptions import NSNitroNserrFtype
from nsexceptions import NSNitroNserrAuth
from nsexceptions import NSNitroNserrNeedauth
from nsexceptions import NSNitroNserrWouldblock
from nsexceptions import NSNitroNserrNocode
from nsexceptions import NSNitroNserrNotsuser
from nsexceptions import NSNitroNserrBigdata
from nsexceptions import NSNitroNserrSmalldata
from nsexceptions import NSNitroNserrNomorent
from nsexceptions import NSNitroNserrNoservice
from nsexceptions import NSNitroNserrOserror
from nsexceptions import NSNitroNserrNonexpcmd
from nsexceptions import NSNitroNserrCmdpropfail
from nsexceptions import NSNitroNserrToomanynodes
from nsexceptions import NSNitroNserrSecondaryfail
from nsexceptions import NSNitroNserrInvalbackup
from nsexceptions import NSNitroNserrNoserver
from nsexceptions import NSNitroNserrLoginreqd
from nsexceptions import NSNitroNserrRpcinval
from nsexceptions import NSNitroNserrNouser
from nsexceptions import NSNitroNserrInvalpasswd
from nsexceptions import NSNitroNserrLicense
from nsexceptions import NSNitroNserrDeferred
from nsexceptions import NSNitroNserrPropauthfail
from nsexceptions import NSNitroNserrNodelsuser
from nsexceptions import NSNitroNserrNomodsuser
from nsexceptions import NSNitroNserrInvalnodeid
from nsexceptions import NSNitroNserrNotopha
from nsexceptions import NSNitroNserrNooppeerbad
from nsexceptions import NSNitroNserrNoopbad
from nsexceptions import NSNitroNserrNopnow
from nsexceptions import NSNitroNserrNooppri
from nsexceptions import NSNitroNserrNoopsec
from nsexceptions import NSNitroNserrRedirect
from nsexceptions import NSNitroNserrBufoverflow
from nsexceptions import NSNitroNserrNouserpolicy
from nsexceptions import NSNitroNserrNosysgroup
from nsexceptions import NSNitroNserrNosyscmdpol
from nsexceptions import NSNitroNserrHaipv6pt
from nsexceptions import NSNitroNserrHansipv6
from nsexceptions import NSNitroNserrNsipv6active
from nsexceptions import NSNitroNserrRtmonStandalone
from nsexceptions import NSNitroNserrIpv6featDisabled
from nsexceptions import NSNitroNserrIprangenotallowd
from nsexceptions import NSNitroNserrIvalidiprange
from nsexceptions import NSNitroNserrIprangemaxlimit
from nsexceptions import NSNitroNserrIpNotExist
from nsexceptions import NSNitroNserrToomanyrules
from nsexceptions import NSNitroNserrPasswdLenMin8
from nsexceptions import NSNitroNserrSyncDisabled
from nsexceptions import NSNitroNserrNodeDisabled
from nsexceptions import NSNitroNserrSyncProgress
from nsexceptions import NSNitroNserrAdnsPerm
from nsexceptions import NSNitroNserrNoincIpsamesubnet
from nsexceptions import NSNitroNserrInvalidPeerip
from nsexceptions import NSNitroNserrRedirect307
from nsexceptions import NSNitroNserrInvalhostname
from nsexceptions import NSNitroNserrRewriteNotSupported
from nsexceptions import NSNitroNserrIpchgDeny
from nsexceptions import NSNitroNserrIpchgGslb
from nsexceptions import NSNitroNserrGslbIpchg
from nsexceptions import NSNitroNserrNoauditsrvc
from nsexceptions import NSNitroNserrLacpkeyNotset
from nsexceptions import NSNitroNserrChannelInusebylacp
from nsexceptions import NSNitroNserrLacpenabled
from nsexceptions import NSNitroNserrIfacemanuallybound
from nsexceptions import NSNitroNserrIntrecinuse
from nsexceptions import NSNitroNserrIpportVipConflict
from nsexceptions import NSNitroNserrIpportVipBound
from nsexceptions import NSNitroNserrNoBackupVip
from nsexceptions import NSNitroNserrReqSetArgs
from nsexceptions import NSNitroNserrSvcgrpMemberNameconflict
from nsexceptions import NSNitroNserrServerNameExist
from nsexceptions import NSNitroNserrMaxServiceBindingOnVserver
from nsexceptions import NSNitroNserrMaxSvcEntityBindingOnSvcgroup
from nsexceptions import NSNitroNserrFsmall
from nsexceptions import NSNitroNserrIntoflow
from nsexceptions import NSNitroNserrAsyncBlocked
from nsexceptions import NSNitroNserrSaclClearpending
from nsexceptions import NSNitroNserrSaclNameExists
from nsexceptions import NSNitroNserrSaclSupersetExists
from nsexceptions import NSNitroNserrSaclSubsetExists
from nsexceptions import NSNitroNserrNoincRoutemonitor
from nsexceptions import NSNitroNserrSessionExpired
from nsexceptions import NSNitroNserrSessionExceeded
from nsexceptions import NSNitroNserrCfeConnExceeded
from nsexceptions import NSNitroNserrCfeConnPerSessExceeded
from nsexceptions import NSNitroNserrCfeKillself
from nsexceptions import NSNitroNserrCfeIncompletesession
from nsexceptions import NSNitroNserrCfeInvalidsession
from nsexceptions import NSNitroNserrCfeSessionNoexist
from nsexceptions import NSNitroNserrSysgroupUserExists
from nsexceptions import NSNitroNserrSysgroupPolicyExists
from nsexceptions import NSNitroNserrSleep
from nsexceptions import NSNitroNserrPpedie
from nsexceptions import NSNitroNserrNoconnCmdpropfail
from nsexceptions import NSNitroNserrTimeoutSecondary
from nsexceptions import NSNitroNserrRpcTimeout
from nsexceptions import NSNitroNserrNotSupported
from nsexceptions import NSNitroNserrNoentVserver
from nsexceptions import NSNitroNserrNoentSvc
from nsexceptions import NSNitroNserrNoentSvcSvcgrp
from nsexceptions import NSNitroNserrHaNov4Netmask
from nsexceptions import NSNitroNserrMaxVsevrverBindingsToService
from nsexceptions import NSNitroNserrSacl6Clearpending
from nsexceptions import NSNitroNserrSacl6NameExists
from nsexceptions import NSNitroNserrSacl6SupersetExists
from nsexceptions import NSNitroNserrSacl6SubsetExists
from nsexceptions import NSNitroNserrNoBackupVipBound
from nsexceptions import NSNitroNserrVserverTypeMismatch
from nsexceptions import NSNitroNserrSessionExpiredRedirect
from nsexceptions import NSNitroNserrCaconfCnflHeurexpRelexp
from nsexceptions import NSNitroNserrCaconfCnflHeurexpRelexpmili
from nsexceptions import NSNitroNserrCaconfCnflRelexpRelexpmili
from nsexceptions import NSNitroNserrCaconfCnflAbsexpHeurexp
from nsexceptions import NSNitroNserrCaconfCnflAbsexpRelexpmili
from nsexceptions import NSNitroNserrCaconfCnflAbsexpgmtHeruexp
from nsexceptions import NSNitroNserrCaconfCnflAbsexpAbsexpgmt
from nsexceptions import NSNitroNserrCaconfCnflAbsexpgmtRelexpmili
from nsexceptions import NSNitroNserrCaconfCnflHitparamsHitslctr
from nsexceptions import NSNitroNserrCaconfCnflInvalparamsHitslctr
from nsexceptions import NSNitroNserrCaconfCnflHitparamsInvlslctr
from nsexceptions import NSNitroNserrCaconfCnflInvalparamsInvlslctr
from nsexceptions import NSNitroNserrCaconfCnflHitslctrMatchcooky
from nsexceptions import NSNitroNserrCaconfCnflHitslctrInvalrest2host
from nsexceptions import NSNitroNserrCaconfCnflHitslctrIgnrparamvalcase
from nsexceptions import NSNitroNserrCaconfCnflInvalslctrMatchcooky
from nsexceptions import NSNitroNserrCaconfCnflInvalslctrInvalrest2host
from nsexceptions import NSNitroNserrCaconfCnflInvalslctrIgnrparamvalcase
from nsexceptions import NSNitroNserrCaconfCnflPosrelexpRelexp
from nsexceptions import NSNitroNserrCaconfCnflPosrelexpRelexpmili
from nsexceptions import NSNitroNserrCaconfCnflAbsexpPosrelexp
from nsexceptions import NSNitroNserrCaconfCnflAbsexpgmtPosrelexp
from nsexceptions import NSNitroNserrCaconfCnflIgnrparamvalcaseHitparams
from nsexceptions import NSNitroNserrCaconfCnflHitInvalparamsMatchcuky
from nsexceptions import NSNitroNserrCaconfCnflInvalrest2hostInvalparam
from nsexceptions import NSNitroNserrCaconfCnflPrefetchPrefetchsec
from nsexceptions import NSNitroNserrCaconfCnflPrefetchPrefetchmili
from nsexceptions import NSNitroNserrCaconfCnflPrefetchmiliPrefetchsec
from nsexceptions import NSNitroNserrCaconfArgLeMinVal
from nsexceptions import NSNitroNserrCaconfArgGeMaxVal
from nsexceptions import NSNitroNserrPxyCacheHmg
from nsexceptions import NSNitroNserrPxyRmLastMemt
from nsexceptions import NSNitroNserrCswInsInvalPfx
from nsexceptions import NSNitroNserrPengExprIvalName
from nsexceptions import NSNitroNserrCswBigUrl
from nsexceptions import NSNitroNserrCswBigPfx
from nsexceptions import NSNitroNserrCswBigSfx
from nsexceptions import NSNitroNserrCswInvalSfx
from nsexceptions import NSNitroNserrExprNomethod
from nsexceptions import NSNitroNserrExprNourltokens
from nsexceptions import NSNitroNserrExprNoversion
from nsexceptions import NSNitroNserrExprNohdr
from nsexceptions import NSNitroNserrExprNocacntl
from nsexceptions import NSNitroNserrExprNoprag
from nsexceptions import NSNitroNserrExprNoquery
from nsexceptions import NSNitroNserrExprNoqual
from nsexceptions import NSNitroNserrActionInuse
from nsexceptions import NSNitroNserrActionHdrInval
from nsexceptions import NSNitroNserrUrlqInval
from nsexceptions import NSNitroNserrUndefAction
from nsexceptions import NSNitroNserrCpeInuse
from nsexceptions import NSNitroNserrCpeReqactInval
from nsexceptions import NSNitroNserrCpeRspactInval
from nsexceptions import NSNitroNserrCpeReqruleInval
from nsexceptions import NSNitroNserrCpeRspruleInval
from nsexceptions import NSNitroNserrActionDefinval
from nsexceptions import NSNitroNserrActionNotpresent
from nsexceptions import NSNitroNserrPxyInvalServicetype
from nsexceptions import NSNitroNserrCachepolicyInuse
from nsexceptions import NSNitroNserrCachegroupInternal
from nsexceptions import NSNitroNserrCpeInval
from nsexceptions import NSNitroNserrExprNolen
from nsexceptions import NSNitroNserrDnswait
from nsexceptions import NSNitroNserrGwTimeout
from nsexceptions import NSNitroNserrCswdmnInuse
from nsexceptions import NSNitroNserrCswdmnPlcyExist
from nsexceptions import NSNitroNserrActionNomodHdr
from nsexceptions import NSNitroNserrExprInvalOperator
from nsexceptions import NSNitroNserrExprDefRemInval
from nsexceptions import NSNitroNserrExprToomany
from nsexceptions import NSNitroNserrActionToomany
from nsexceptions import NSNitroNserrCswpolicyToomany
from nsexceptions import NSNitroNserrCrdpolicyToomany
from nsexceptions import NSNitroNserrMappolicyToomany
from nsexceptions import NSNitroNserrFiltpolicyToomany
from nsexceptions import NSNitroNserrCachepolicyToomany
from nsexceptions import NSNitroNserrCachegroupToomany
from nsexceptions import NSNitroNserrCacheparamMemallocFailed
from nsexceptions import NSNitroNserrCachegroupInuse
from nsexceptions import NSNitroNserrCachegroupExpconflict
from nsexceptions import NSNitroNserrCacheparamInval
from nsexceptions import NSNitroNserrCachegroupParamInval
from nsexceptions import NSNitroNserrCachegroupQueryInval
from nsexceptions import NSNitroNserrActionInval
from nsexceptions import NSNitroNserrExprDefSetInval
from nsexceptions import NSNitroNserrCachegroupResszMinGtMax
from nsexceptions import NSNitroNserrFiltacionInvalrespcode
from nsexceptions import NSNitroNserrCachegroupHostReq
from nsexceptions import NSNitroNserrCachegroupHostNreq
from nsexceptions import NSNitroNserrCachegroupDyngrpNexp
from nsexceptions import NSNitroNserrCachegroupOneGrpReq
from nsexceptions import NSNitroNserrCachegroupOneAllReq
from nsexceptions import NSNitroNserrCachegroupMatchParamInval
from nsexceptions import NSNitroNserrCachegroupDynResCache
from nsexceptions import NSNitroNserrExprInvalValue
from nsexceptions import NSNitroNserrCachegroupPrefetchConflict
from nsexceptions import NSNitroNserrCachegroupPrefetchEnable
from nsexceptions import NSNitroNserrCachegroupCchUnknown
from nsexceptions import NSNitroNserrCachegroupRelexpX10ms
from nsexceptions import NSNitroNserrCachegroupPrefetchX10ms
from nsexceptions import NSNitroNserrCachegroupStaticToDynamic
from nsexceptions import NSNitroNserrPlcyDefRemInval
from nsexceptions import NSNitroNserrCachegroupPrefetchRelNreq
from nsexceptions import NSNitroNserrExprSetInvalFlowtype
from nsexceptions import NSNitroNserrExprTooBig
from nsexceptions import NSNitroNserrCpeInvalidIdrange
from nsexceptions import NSNitroNserrExprTooBigExt
from nsexceptions import NSNitroNserrCachegroupMatchcookieDynReq
from nsexceptions import NSNitroNserrCachegroupMatchcookieNreq
from nsexceptions import NSNitroNserrCachefwpxyPresent
from nsexceptions import NSNitroNserrCachePrefetchReevalNreq
from nsexceptions import NSNitroNserrCachefwpxyToomany
from nsexceptions import NSNitroNserrCachePetFcNreq
from nsexceptions import NSNitroNserrSaveconfigInProgress
from nsexceptions import NSNitroNserrGwsubnetNotExist
from nsexceptions import NSNitroNserrGwReqSubnet
from nsexceptions import NSNitroNserrUrlpolNoPri
from nsexceptions import NSNitroNserrBadCrAttribs
from nsexceptions import NSNitroNserrMacNotSupported
from nsexceptions import NSNitroNserrPolicyNotSupported
from nsexceptions import NSNitroNserrCacheabilityNotSupported
from nsexceptions import NSNitroNserrHostRtNotAllowed
from nsexceptions import NSNitroNserrRoutingNotAllowed
from nsexceptions import NSNitroNserrConfigNotsaved
from nsexceptions import NSNitroNserrExprmismatch
from nsexceptions import NSNitroNserrNoHost
from nsexceptions import NSNitroNserrNoDflt
from nsexceptions import NSNitroNserrDfltdmnFirst
from nsexceptions import NSNitroNserrPxyConfLoop
from nsexceptions import NSNitroNserrPxyMeDup
from nsexceptions import NSNitroNserrPxyIvalTgt
from nsexceptions import NSNitroNserrConnected
from nsexceptions import NSNitroNserrAuthenticate
from nsexceptions import NSNitroNserrLargeDomain
from nsexceptions import NSNitroNserrPxyIvalUrl
from nsexceptions import NSNitroNserrPxyMeUse
from nsexceptions import NSNitroNserrPxyMtType
from nsexceptions import NSNitroNserrPxyMtUse
from nsexceptions import NSNitroNserrPxyMbInval
from nsexceptions import NSNitroNserrPxyMbUse
from nsexceptions import NSNitroNserrPxySetdcdn
from nsexceptions import NSNitroNserrPxySetdflt
from nsexceptions import NSNitroNserrPxyDfltNotset
from nsexceptions import NSNitroNserrPxyFwdIval
from nsexceptions import NSNitroNserrPxyMtxProt
from nsexceptions import NSNitroNserrPxyMtxTra
from nsexceptions import NSNitroNserrPxyMtxFwd
from nsexceptions import NSNitroNserrPxyMtxRev
from nsexceptions import NSNitroNserrPxyAddTraNonhttp
from nsexceptions import NSNitroNserrPxyAddTraOther
from nsexceptions import NSNitroNserrPxyOptInval
from nsexceptions import NSNitroNserrPxyAddSvrOther
from nsexceptions import NSNitroNserrPxyMbDup
from nsexceptions import NSNitroNserrPxyDfltDup
from nsexceptions import NSNitroNserrSelInuse
from nsexceptions import NSNitroNserrSelParseFailed
from nsexceptions import NSNitroNserrNoselector
from nsexceptions import NSNitroNserrSelToomany
from nsexceptions import NSNitroNserrCachegroupNoselparam
from nsexceptions import NSNitroNserrNocachegroup
from nsexceptions import NSNitroNserrNonreqSel
from nsexceptions import NSNitroNserrInvalarg
from nsexceptions import NSNitroNserrNowildAllowed
from nsexceptions import NSNitroNserrDateIncompat
from nsexceptions import NSNitroNserrTimedateInvalid
from nsexceptions import NSNitroNserrContentgroupCookieReqParam
from nsexceptions import NSNitroNserrContentgroupIgnorecaseReqHitparam
from nsexceptions import NSNitroNserrContentgroupInvalparamReq
from nsexceptions import NSNitroNserrClisecExpTooLong
from nsexceptions import NSNitroNserrNonhttpCswBindHttpSslPolicy
from nsexceptions import NSNitroNserrNonhttpCswBindDomainPolicy
from nsexceptions import NSNitroNserrNonhttpCswBindUrlPolicy
from nsexceptions import NSNitroNserrPolboundtoTooManyVsvrs
from nsexceptions import NSNitroNserrPiCswUrlDomain
from nsexceptions import NSNitroNserrPiToPeCsw
from nsexceptions import NSNitroNserrPeToPiCsw
from nsexceptions import NSNitroNserrPriorityCompPiCsw
from nsexceptions import NSNitroNserrPiTcpcsw
from nsexceptions import NSNitroNserrPeGoto
from nsexceptions import NSNitroNserrPiToPePolCsw
from nsexceptions import NSNitroNserrCacheobjectEvict
from nsexceptions import NSNitroNserrDnsfail
from nsexceptions import NSNitroNserrHcRetTypeChange
from nsexceptions import NSNitroNserrHcNotHttpVs
from nsexceptions import NSNitroNserrHcReqConfigXor
from nsexceptions import NSNitroNserrHcServiceConfigXor
from nsexceptions import NSNitroNserrHcRetTypeReqd
from nsexceptions import NSNitroNserrRtspCswBindIpPolicy
from nsexceptions import NSNitroNserrCswBindIncompatTgt
from nsexceptions import NSNitroNserrAsBadXmlnamespacePrefix
from nsexceptions import NSNitroNserrInvalidSipExpr
from nsexceptions import NSNitroNserrNoBackendvserver
from nsexceptions import NSNitroNserrContentGroupToomany
from nsexceptions import NSNitroNserrCacheMemSizeChanged
from nsexceptions import NSNitroNserrCacheMemSizeZero
from nsexceptions import NSNitroNserrL2connNotAllowed
from nsexceptions import NSNitroNserrSqlNotAllowed
from nsexceptions import NSNitroNserrIpsecNotAllowed
from nsexceptions import NSNitroNserrCswBindIncompatBkup
from nsexceptions import NSNitroNserrRnatInv
from nsexceptions import NSNitroNserrInvalidIf
from nsexceptions import NSNitroNserrMgrlimitReached
from nsexceptions import NSNitroNserrSpInvaldTable
from nsexceptions import NSNitroNserrRnatNatipExists
from nsexceptions import NSNitroNserrRnatExists
from nsexceptions import NSNitroNserrRnatNotExists
from nsexceptions import NSNitroNserrRnatNatipNotExists
from nsexceptions import NSNitroNserrRnatInvalidNatip
from nsexceptions import NSNitroNserrArpDisabled
from nsexceptions import NSNitroNserrArpSecNotOwnedip
from nsexceptions import NSNitroNserrCpeRuleInval
from nsexceptions import NSNitroNserrInvalFlowtype
from nsexceptions import NSNitroNserrInvalPolicyType
from nsexceptions import NSNitroNserrCpeRuleActionInval
from nsexceptions import NSNitroNserrCpeDefSetInval
from nsexceptions import NSNitroNserrInvalForcecleanup
from nsexceptions import NSNitroNserrInvalAaaGroup
from nsexceptions import NSNitroNserrInvalProxy
from nsexceptions import NSNitroNserrInvalHtttpproxy
from nsexceptions import NSNitroNserrInvalFtpproxy
from nsexceptions import NSNitroNserrInvalSockproxy
from nsexceptions import NSNitroNserrInvalGopherproxy
from nsexceptions import NSNitroNserrInvalSslproxy
from nsexceptions import NSNitroNserrInvalAaagrpMax
from nsexceptions import NSNitroNserrInvalMaxPortNum
from nsexceptions import NSNitroNserrInvalHttpport
from nsexceptions import NSNitroNserrInvalVpnvsererPoltype
from nsexceptions import NSNitroNserrInvalVpnglobalPoltype
from nsexceptions import NSNitroNserrCpeRemInuse
from nsexceptions import NSNitroNserrProxyConflict
from nsexceptions import NSNitroNserrProxyInval
from nsexceptions import NSNitroNserrPxyexcptInval
from nsexceptions import NSNitroNserrCpePoltypeNoCse
from nsexceptions import NSNitroNserrSessactCseIncompatible
from nsexceptions import NSNitroNserrNomemCse
from nsexceptions import NSNitroNserrIncompatFsRule
from nsexceptions import NSNitroNserrIncompatFsMix
from nsexceptions import NSNitroNserrDrEnable
from nsexceptions import NSNitroNserrMaxDistance
from nsexceptions import NSNitroNserrNullRouteDistance
from nsexceptions import NSNitroNserrBadActionTcpProfileType
from nsexceptions import NSNitroNserrBadActionHttpProfileType
from nsexceptions import NSNitroNserrSpInvalidThreshold
from nsexceptions import NSNitroNserrVipRouteExists
from nsexceptions import NSNitroNserrAclNotExists
from nsexceptions import NSNitroNserrAclExists
from nsexceptions import NSNitroNserrAclpipWosrcdst
from nsexceptions import NSNitroNserrAclSameipPip
from nsexceptions import NSNitroNserrAclInvalPeerip
from nsexceptions import NSNitroNserrAclIppipExists
from nsexceptions import NSNitroNserrXacldelerror
from nsexceptions import NSNitroNserrXacladderror
from nsexceptions import NSNitroNserrXaclPriorityExists
from nsexceptions import NSNitroNserrXaclIcmpReqd
from nsexceptions import NSNitroNserrNoloopback
from nsexceptions import NSNitroNserrInvicmptype
from nsexceptions import NSNitroNserrInvicmpcode
from nsexceptions import NSNitroNserrXaclrnatdel
from nsexceptions import NSNitroNserrXaclmodcfginfo
from nsexceptions import NSNitroNserrAcl6IppipExists
from nsexceptions import NSNitroNserrAcl6Delerror
from nsexceptions import NSNitroNserrAcl6Adderror
from nsexceptions import NSNitroNserrAcl6PriorityExists
from nsexceptions import NSNitroNserrAcl6IcmpReqd
from nsexceptions import NSNitroNserrAcl6Unspecaddr
from nsexceptions import NSNitroNserrAcl6Modcfginfo
from nsexceptions import NSNitroNserrAcl6Prefixlen
from nsexceptions import NSNitroNserrPbrNexthopNotdirect
from nsexceptions import NSNitroNserrPbrNoloopback
from nsexceptions import NSNitroNserrPbrdelerror
from nsexceptions import NSNitroNserrPbrIppipExists
from nsexceptions import NSNitroNserrPbrPriorityExists
from nsexceptions import NSNitroNserrPbrmodcfginfo
from nsexceptions import NSNitroNserrPbrNexthopReqd
from nsexceptions import NSNitroNserrPbrL2ConfigInfo
from nsexceptions import NSNitroNserrPbrmodcfgL2Info
from nsexceptions import NSNitroNserrPbrNoMonitorGateway
from nsexceptions import NSNitroNserrPbrInvalidIporgateway
from nsexceptions import NSNitroNserrPbrMaxRuleExceeded
from nsexceptions import NSNitroNserrTcpconnfail
from nsexceptions import NSNitroNserrLoginfail
from nsexceptions import NSNitroNserrNologin
from nsexceptions import NSNitroNserrAuthtimeout
from nsexceptions import NSNitroNserrNotPrimary
from nsexceptions import NSNitroNserrRemoteop
from nsexceptions import NSNitroNserrConnlost
from nsexceptions import NSNitroNserrRpcdatamismatch
from nsexceptions import NSNitroNserrRpcbadreply
from nsexceptions import NSNitroNserrUnabletoprompt
from nsexceptions import NSNitroNserrUserabort
from nsexceptions import NSNitroNserrEof
from nsexceptions import NSNitroNserrInterrupt
from nsexceptions import NSNitroNserrInternal
from nsexceptions import NSNitroNserrStrmaxlen255
from nsexceptions import NSNitroNserrStrmaxlen32
from nsexceptions import NSNitroNserrNoresponse
from nsexceptions import NSNitroNserrIoerror
from nsexceptions import NSNitroNserrEnv
from nsexceptions import NSNitroNserrCmdsfailed
from nsexceptions import NSNitroNserrAllcmdsfailed
from nsexceptions import NSNitroNserrInvalidTcpOptionType
from nsexceptions import NSNitroNserrLicexpired
from nsexceptions import NSNitroNserrFeatdisabled
from nsexceptions import NSNitroNserrMaxlimit
from nsexceptions import NSNitroNserrSetNosupport
from nsexceptions import NSNitroNserrInvalidvalue
from nsexceptions import NSNitroNserrInvalidname
from nsexceptions import NSNitroNserrNosuchcmd
from nsexceptions import NSNitroNserrCmdambiguous
from nsexceptions import NSNitroNserrNosucharg
from nsexceptions import NSNitroNserrArgvalmissing
from nsexceptions import NSNitroNserrArgsmutex
from nsexceptions import NSNitroNserrArgprereq
from nsexceptions import NSNitroNserrArgstoofew
from nsexceptions import NSNitroNserrArgmissing
from nsexceptions import NSNitroNserrArgorder
from nsexceptions import NSNitroNserrArgvalbad
from nsexceptions import NSNitroNserrArgvalseq
from nsexceptions import NSNitroNserrArgambiguous
from nsexceptions import NSNitroNserrSyncgslbconfig
from nsexceptions import NSNitroNserrSyncgslbconfigWarn
from nsexceptions import NSNitroNserrArgvalsneq
from nsexceptions import NSNitroNserrArgvalambiguous
from nsexceptions import NSNitroNserrStrmaxlen
from nsexceptions import NSNitroNserrStrminlen
from nsexceptions import NSNitroNserrIntmaxval
from nsexceptions import NSNitroNserrIntminval
from nsexceptions import NSNitroNserrInvalidip
from nsexceptions import NSNitroNserrInvalidnetmask
from nsexceptions import NSNitroNserrToomanyvals
from nsexceptions import NSNitroNserrBadrange
from nsexceptions import NSNitroNserrExprquotes
from nsexceptions import NSNitroNserrBadquotes
from nsexceptions import NSNitroNserrInvalidrange
from nsexceptions import NSNitroNserrMismatchranges
from nsexceptions import NSNitroNserrMultiranges
from nsexceptions import NSNitroNserrNomatchchar
from nsexceptions import NSNitroNserrNeedreboot
from nsexceptions import NSNitroNsqSaveconfig
from nsexceptions import NSNitroNserrNotsaved
from nsexceptions import NSNitroNserrCmdexec
from nsexceptions import NSNitroNsqReboot
from nsexceptions import NSNitroNserrNoreboot
from nsexceptions import NSNitroNserrPgmfailed
from nsexceptions import NSNitroNserrCtxmode
from nsexceptions import NSNitroNserrCmdincomplete
from nsexceptions import NSNitroNserrCmdoutofctx
from nsexceptions import NSNitroNserrConfigsaved
from nsexceptions import NSNitroNserrConfigcleared
from nsexceptions import NSNitroNserrRebooting
from nsexceptions import NSNitroNserrNoconfigsave
from nsexceptions import NSNitroNserrRegexnoanchor
from nsexceptions import NSNitroNserrRegexnomatch
from nsexceptions import NSNitroNserrRegexinvalid
from nsexceptions import NSNitroNserrRegexnotallowed
from nsexceptions import NSNitroNserrRegexnocmd
from nsexceptions import NSNitroNserrInvalidipv6Format
from nsexceptions import NSNitroNserrInvalidipv6TwoDoubecolon
from nsexceptions import NSNitroNserrInvalidipv6NoprefixLength
from nsexceptions import NSNitroNserrInvalidipv6PrefixValue
from nsexceptions import NSNitroNserrTermnameinvalid
from nsexceptions import NSNitroNserrTerminvalid
from nsexceptions import NSNitroNserrForcefailover
from nsexceptions import NSNitroNserrForcefailHealthWarn
from nsexceptions import NSNitroNserrHellotimeMultiple
from nsexceptions import NSNitroNserrForcesyncsave
from nsexceptions import NSNitroNserrErroutfilename
from nsexceptions import NSNitroNserrRnatipdel
from nsexceptions import NSNitroNserrInvalidalias
from nsexceptions import NSNitroNserrNosuchalias
from nsexceptions import NSNitroNserrAliasexists
from nsexceptions import NSNitroNserrNosuchfile
from nsexceptions import NSNitroNserrNotregfile
from nsexceptions import NSNitroNserrDeprcmd
from nsexceptions import NSNitroNserrDeprarg
from nsexceptions import NSNitroNserrNotlogfile
from nsexceptions import NSNitroNserrNoplenforipv6range
from nsexceptions import NSNitroNserrInvalidint
from nsexceptions import NSNitroNserrCmdambiguousUsecompletionsoptions
from nsexceptions import NSNitroNserrMetadataInvalEntitytype
from nsexceptions import NSNitroNserrSetnotexist
from nsexceptions import NSNitroNserrSetargnotexist
from nsexceptions import NSNitroNserrInvalidDs
from nsexceptions import NSNitroNserrNosuchcounter
from nsexceptions import NSNitroNserrInvalidipmask
from nsexceptions import NSNitroNserrInvalidippat
from nsexceptions import NSNitroNserrBadrc
from nsexceptions import NSNitroNserrInvalidrangetype
from nsexceptions import NSNitroNserrInvalidrangeval
from nsexceptions import NSNitroNserrInvalidipv6PrefixLength
from nsexceptions import NSNitroNserrEntitydeleteFail
from nsexceptions import NSNitroNserrIncompatibleip
from nsexceptions import NSNitroNserrTranscrIp
from nsexceptions import NSNitroNserrPasswordMismatch
from nsexceptions import NSNitroNserrNosuchioctl
from nsexceptions import NSNitroNserrNotargets
from nsexceptions import NSNitroNserrCantrecover
from nsexceptions import NSNitroNserrIgnoredioctl
from nsexceptions import NSNitroNserrRemoteclose
from nsexceptions import NSNitroNserrInvalidTarget
from nsexceptions import NSNitroNserrFileError
from nsexceptions import NSNitroNserrCommentDropped
from nsexceptions import NSNitroNserrAggreqTimeout
from nsexceptions import NSNitroNserrAggread
from nsexceptions import NSNitroNserrRpcCmdDup
from nsexceptions import NSNitroNserrRpcCmdNondup
from nsexceptions import NSNitroNserrCfePeComm
from nsexceptions import NSNitroNserrAggConfail
from nsexceptions import NSNitroNserrCfePeTimout
from nsexceptions import NSNitroNserrAggInvalidresponse
from nsexceptions import NSNitroNserrNontpsvr
from nsexceptions import NSNitroNserrAggSendfail
from nsexceptions import NSNitroNserrCfeAslearnComm
from nsexceptions import NSNitroNserrNitroInvalidObjectname
from nsexceptions import NSNitroNserrNitroInvalidJsonInput
from nsexceptions import NSNitroNserrNitroInvalidJsonDatatype
from nsexceptions import NSNitroNserrNitroInvalidXmlInput
from nsexceptions import NSNitroNserrNitroInvalidDatatype
from nsexceptions import NSNitroNserrNitroInvalidMethod
from nsexceptions import NSNitroNserrNitroParseError
from nsexceptions import NSNitroNserrNitroCmdexecFailed
from nsexceptions import NSNitroNserrNitroInvalidAction
from nsexceptions import NSNitroNserrNsappTemplateExists
from nsexceptions import NSNitroNserrNsappInvalidTemplate
from nsexceptions import NSNitroNserrNsappDirError
from nsexceptions import NSNitroNserrNsappFileError
from nsexceptions import NSNitroNserrNsappInvalidAppInput
from nsexceptions import NSNitroNserrNsappExceededFilelength
from nsexceptions import NSNitroNserrNsappEndpointInuse
from nsexceptions import NSNitroNserrNsappProtocolMismatch
from nsexceptions import NSNitroNserrNsappInvalidVarname
from nsexceptions import NSNitroNserrNsappZipFile
from nsexceptions import NSNitroNserrNsappMaxepReached
from nsexceptions import NSNitroNserrNsappNotExist
from nsexceptions import NSNitroNserrNsappInvalidServicetype
from nsexceptions import NSNitroNserrNsappTemplateFormatError
from nsexceptions import NSNitroNserrNsappAppWithoutAppunits
from nsexceptions import NSNitroNserrNsappServicrgroupExists
from nsexceptions import NSNitroNserrSlesslbLbmethodNotsupported
from nsexceptions import NSNitroNserrSlesslbPersistNotsupported
from nsexceptions import NSNitroNserrSlesslbTypeNotsupported
from nsexceptions import NSNitroNserrSlesslbModeNotsupported
from nsexceptions import NSNitroNserrSlesslbSvcUsipnotset
from nsexceptions import NSNitroNserrWildcardvipLbmethodInval
from nsexceptions import NSNitroNserrWildcardvipPersistInval
from nsexceptions import NSNitroNserrLbSoThreshold
from nsexceptions import NSNitroNserrConnfailoverUsip
from nsexceptions import NSNitroNserrConnfailoverService
from nsexceptions import NSNitroNserrLbSoDynamicconThreshold
from nsexceptions import NSNitroNserrLbSoAddrvip
from nsexceptions import NSNitroNserrConnfailoverNotforSless
from nsexceptions import NSNitroNserrSipNocallid
from nsexceptions import NSNitroNserrSipNovia
from nsexceptions import NSNitroNserrSipNocseq
from nsexceptions import NSNitroNserrSipNoto
from nsexceptions import NSNitroNserrSipNofrom
from nsexceptions import NSNitroNserrSipNomaxForwards
from nsexceptions import NSNitroNserrSipServiceUnavailable
from nsexceptions import NSNitroNserrSvcNotBound
from nsexceptions import NSNitroNserrSvctypeMismatch
from nsexceptions import NSNitroNserrChConNotAllowed
from nsexceptions import NSNitroNserrChIncompleteHdr
from nsexceptions import NSNitroNserrSpilloverdisabled
from nsexceptions import NSNitroNserrMaxtimeexceeded
from nsexceptions import NSNitroNserrScinvalproto
from nsexceptions import NSNitroNserrRootrec
from nsexceptions import NSNitroNserrRootGluerec
from nsexceptions import NSNitroNserrVipinsertNotSupported
from nsexceptions import NSNitroNserrVsvrAlrdyBound
from nsexceptions import NSNitroNserrInvalidWlmBinding
from nsexceptions import NSNitroNserrVsvrNotBound
from nsexceptions import NSNitroNserrWlmExists
from nsexceptions import NSNitroNserrInvalidTimeout
from nsexceptions import NSNitroNserrConnfailoverIncmode
from nsexceptions import NSNitroNserrConnfailoverTcpb
from nsexceptions import NSNitroNserrConnfailoverTcpbSvcBind
from nsexceptions import NSNitroNserrConnfailoverTcpbSvcParam
from nsexceptions import NSNitroNserrConnfailoverServiceStatefull
from nsexceptions import NSNitroNserrConnfailoverSslSvcBind
from nsexceptions import NSNitroNserrConnfailoverHaIncNode
from nsexceptions import NSNitroNserrConnfailoverSslSvc
from nsexceptions import NSNitroNserrInvalidPersistence
from nsexceptions import NSNitroNserrRtspsessionInvalid
from nsexceptions import NSNitroNserrLbMethodSameasBackupMethod
from nsexceptions import NSNitroNserrServerExist
from nsexceptions import NSNitroNserrLbSoHealth
from nsexceptions import NSNitroNserrReqRuleMissing
from nsexceptions import NSNitroNserrConnfailoverBindlo
from nsexceptions import NSNitroNserrConnfailoverSetwithlo
from nsexceptions import NSNitroNserrRedirectUrlNotApplicable
from nsexceptions import NSNitroNserrStatefulConnfailoverIpv6
from nsexceptions import NSNitroNserrConnfailoverNotSupported
from nsexceptions import NSNitroNserrNobindOnpush
from nsexceptions import NSNitroNserrPushVsvr
from nsexceptions import NSNitroNserrOnlyHttpssl
from nsexceptions import NSNitroNserrPushBindExists
from nsexceptions import NSNitroNserrSetPushvsOnly
from nsexceptions import NSNitroNserrSlessNoSupport
from nsexceptions import NSNitroNserrConnfailoverV6service
from nsexceptions import NSNitroNserrConnfailoverVserver
from nsexceptions import NSNitroNserrNoListenPolicyForDummyvs
from nsexceptions import NSNitroNserrNormalVsNoneListenpol
from nsexceptions import NSNitroNserrNoLispriForNoneLispol
from nsexceptions import NSNitroNserrInvalidPolicyString
from nsexceptions import NSNitroNserrNodatalenoffforvs
from nsexceptions import NSNitroNserrLbgrppersiswithrdp
from nsexceptions import NSNitroNserrPqBindvip
from nsexceptions import NSNitroNserrPqInvalprio
from nsexceptions import NSNitroNserrPq2bigrule
from nsexceptions import NSNitroNserrPqInvalwt
from nsexceptions import NSNitroNserrPqPolexist
from nsexceptions import NSNitroNserrPqNopol
from nsexceptions import NSNitroNserrPq2manyref
from nsexceptions import NSNitroNserrPqNolbvip
from nsexceptions import NSNitroNserrPqPhsconfig
from nsexceptions import NSNitroNserrPqNobind
from nsexceptions import NSNitroNserrSslCert
from nsexceptions import NSNitroNserrSslPkey
from nsexceptions import NSNitroNserrSslNomatch
from nsexceptions import NSNitroNserrSslCerttype
from nsexceptions import NSNitroNserrSslNocert
from nsexceptions import NSNitroNserrSslRefext
from nsexceptions import NSNitroNserrSslBind
from nsexceptions import NSNitroNserrSslLink
from nsexceptions import NSNitroNserrSslNeedSslproto
from nsexceptions import NSNitroNserrSslNolink
from nsexceptions import NSNitroNserrSslBindor
from nsexceptions import NSNitroNserrSslNosvrcert
from nsexceptions import NSNitroNserrSslIssubmis
from nsexceptions import NSNitroNserrSslCrl
from nsexceptions import NSNitroNserrSslNocrl
from nsexceptions import NSNitroNserrSslDhcount
from nsexceptions import NSNitroNserrSslSessto
from nsexceptions import NSNitroNserrSslErsacount
from nsexceptions import NSNitroNserrSslDhSize
from nsexceptions import NSNitroNserrDhpath
from nsexceptions import NSNitroNserrCertheader
from nsexceptions import NSNitroNserrSessheader
from nsexceptions import NSNitroNserrCipherPerm
from nsexceptions import NSNitroNserrSslErsadisabled
from nsexceptions import NSNitroNserrSslDhdisabled
from nsexceptions import NSNitroNserrSslSessdisabled
from nsexceptions import NSNitroNserrSslPkeySize
from nsexceptions import NSNitroNserrSslNotApplicable
from nsexceptions import NSNitroNserrSslInternalerr
from nsexceptions import NSNitroNserrSslNocacert
from nsexceptions import NSNitroNserrSslRefreshdis
from nsexceptions import NSNitroNserrSslSvrportneeded
from nsexceptions import NSNitroNserrSslBaseobjneeded
from nsexceptions import NSNitroNserrSslCipherRedirect
from nsexceptions import NSNitroNserrSslNodsa
from nsexceptions import NSNitroNserrSslFipsrefext
from nsexceptions import NSNitroNserrSslNofipskey
from nsexceptions import NSNitroNserrNofipscard
from nsexceptions import NSNitroNserrFipscardnotconf
from nsexceptions import NSNitroNserrSslSslv2Redirect
from nsexceptions import NSNitroNserrSslModsize64
from nsexceptions import NSNitroNserrSslNonfipskey
from nsexceptions import NSNitroNserrNfipsFipsUpd
from nsexceptions import NSNitroNserrFipsNfipsUpd
from nsexceptions import NSNitroNserrSslIssuerNotinGlbcertlist
from nsexceptions import NSNitroNserrSslCrlsigcheckFail
from nsexceptions import NSNitroNserrSslPortrewrite
from nsexceptions import NSNitroNserrSslSslv2RenegClientCert
from nsexceptions import NSNitroNserrSslBrklink
from nsexceptions import NSNitroNserrSslCertNotYetValid
from nsexceptions import NSNitroNserrSslCertExpired
from nsexceptions import NSNitroNserrSslExpiredBrklink
from nsexceptions import NSNitroNserrSslNyvalidBrklink
from nsexceptions import NSNitroNserrSslOcspRespcert
from nsexceptions import NSNitroNserrSslOcspSigncert
from nsexceptions import NSNitroNserrSslOcspAia
from nsexceptions import NSNitroNserrSslFipscardlocked
from nsexceptions import NSNitroNserrSslDomincompat
from nsexceptions import NSNitroNserrSslNomthdchange
from nsexceptions import NSNitroNserrSslUrlsrvrneeded
from nsexceptions import NSNitroNserrSslInvalidUrl
from nsexceptions import NSNitroNserrSslMixparams
from nsexceptions import NSNitroNserrSslPkeyMinsize
from nsexceptions import NSNitroNserrSslSyncinprogress
from nsexceptions import NSNitroNserrSslSyncfailed
from nsexceptions import NSNitroNserrSslCiphgrpRefcnt
from nsexceptions import NSNitroNserrSslCvmNodsa
from nsexceptions import NSNitroNserrCerthashheader
from nsexceptions import NSNitroNserrSslCrlinrefresh
from nsexceptions import NSNitroNserrSslCrlmemExceeds
from nsexceptions import NSNitroNserrSslCrlindeletion
from nsexceptions import NSNitroNserrSslIndeleteNorefresh
from nsexceptions import NSNitroNserrSslInrefreshNodelete
from nsexceptions import NSNitroNserrNomix
from nsexceptions import NSNitroNserrNopolicyNontrsvc
from nsexceptions import NSNitroNserrSslSslpolBindConst
from nsexceptions import NSNitroNserrSslNoUsableCiphers
from nsexceptions import NSNitroNserrSslCertNotCa
from nsexceptions import NSNitroNserrSslCacertNoCrlsign
from nsexceptions import NSNitroNserrSslCrlExpired
from nsexceptions import NSNitroNserrSslCrlNotyetValid
from nsexceptions import NSNitroNserrSslParsingDeltaCrlExtn
from nsexceptions import NSNitroNserrSslDeltaCrlMissingBaseCrl
from nsexceptions import NSNitroNserrNofipscipher
from nsexceptions import NSNitroNserrNofipsciphergrp
from nsexceptions import NSNitroNserrNonfipsciphertogrp
from nsexceptions import NSNitroNserrNonfipsaliastogrp
from nsexceptions import NSNitroNserrNonfipsgrouptogrp
from nsexceptions import NSNitroNserrSslImportFipskeyNameMismatch
from nsexceptions import NSNitroNserrSslPkeySizeCa
from nsexceptions import NSNitroNserrSslCrlPortMismatch
from nsexceptions import NSNitroNserrSslPkeySizeVpx
from nsexceptions import NSNitroNserrSslDhSizeVpx
from nsexceptions import NSNitroNserrNoentCipher
from nsexceptions import NSNitroNserrFipsfwwrongmajor
from nsexceptions import NSNitroNserrFipsfwwrongminor
from nsexceptions import NSNitroNserrFipsfwupdated
from nsexceptions import NSNitroNserrSslPendingCmds
from nsexceptions import NSNitroNserrFipsfwupdatedoreboot
from nsexceptions import NSNitroNserrSslSniNotenable
from nsexceptions import NSNitroNserrSslNoCn
from nsexceptions import NSNitroNserrSslDupSnicert
from nsexceptions import NSNitroNserrSslSniNotvalidServ
from nsexceptions import NSNitroNserrOcspReferences
from nsexceptions import NSNitroNserrOcspSignerNokey
from nsexceptions import NSNitroNserrSslNotSupported
from nsexceptions import NSNitroNserrOcspTooManyResponders
from nsexceptions import NSNitroNserrOcspNoDnsServerConfigured
from nsexceptions import NSNitroNserrSslDupSnicertBrklink
from nsexceptions import NSNitroNserrSslNoCnBrllink
from nsexceptions import NSNitroNserrNgfipsresetreboot
from nsexceptions import NSNitroNserrNgfipsinitreboot
from nsexceptions import NSNitroNserrFipscmdtimeout
from nsexceptions import NSNitroNserrSslSimtimeout
from nsexceptions import NSNitroNserrSslNgfipsQfull
from nsexceptions import NSNitroNserrSslNomemVsvrsrvlistnode
from nsexceptions import NSNitroNserrSslCertkeySize64
from nsexceptions import NSNitroNserrSniAtk
from nsexceptions import NSNitroNserrSniNohosthdr
from nsexceptions import NSNitroNserrCrlShmemAllocFail
from nsexceptions import NSNitroNserrSslCertMissingParam
from nsexceptions import NSNitroNserrSslNomemCertkeyOcsprespListnode
from nsexceptions import NSNitroNserrSslBundleIcFileExists
from nsexceptions import NSNitroNserrSslBundleScertMissing
from nsexceptions import NSNitroNserrSslBundleCertMissing
from nsexceptions import NSNitroNserrSslBundleFailed
from nsexceptions import NSNitroNserrSslBundleParseErr
from nsexceptions import NSNitroNserrSslBundleMaxCert
from nsexceptions import NSNitroNserrSslBundleMaxKey
from nsexceptions import NSNitroNserrSslBundleIcFileCreateFailed
from nsexceptions import NSNitroNserrSslIssuerMismatch
from nsexceptions import NSNitroNserrSslConffile
from nsexceptions import NSNitroNserrSslNoconffile
from nsexceptions import NSNitroNserrSslSigfail
from nsexceptions import NSNitroNserrSslInvalformat
from nsexceptions import NSNitroNserrSslOutfile
from nsexceptions import NSNitroNserrSslVerifyFail
from nsexceptions import NSNitroNserrSslFilecreate
from nsexceptions import NSNitroNserrSslMinkeysize
from nsexceptions import NSNitroNserrSslInvalidReq
from nsexceptions import NSNitroNserrSslGentool
from nsexceptions import NSNitroNserrSslPemOnly
from nsexceptions import NSNitroNserrSslPassmismatch
from nsexceptions import NSNitroNserrSslPassreq
from nsexceptions import NSNitroNserrSslInvalpass
from nsexceptions import NSNitroNserrSslMaxkeysize
from nsexceptions import NSNitroNserrSslGntoolargMissing
from nsexceptions import NSNitroNserrSslInvalPubexp
from nsexceptions import NSNitroNserrSslInvalidValue
from nsexceptions import NSNitroNserrSslMissingKval
from nsexceptions import NSNitroNserrSslInvalDhgen
from nsexceptions import NSNitroNserrSslNofileCertreq
from nsexceptions import NSNitroNserrSslReqNomatch
from nsexceptions import NSNitroNserrSslPkcs12
from nsexceptions import NSNitroNserrSslNofileCapvtkey
from nsexceptions import NSNitroNserrSslNofileCacert
from nsexceptions import NSNitroNserrSslNofileSerial
from nsexceptions import NSNitroNserrSslNofilePkcs12
from nsexceptions import NSNitroNserrSslReadCacert
from nsexceptions import NSNitroNserrReadCert
from nsexceptions import NSNitroNserrImpExpNotTogether
from nsexceptions import NSNitroNserrNofileCert
from nsexceptions import NSNitroNserrNofileKey
from nsexceptions import NSNitroNserrCacertpkeyMismatch
from nsexceptions import NSNitroNserrWrongRevEntry
from nsexceptions import NSNitroNserrWrongRevDate
from nsexceptions import NSNitroNserrWrongSerialNo
from nsexceptions import NSNitroNserrCreateDatabaseEntry
from nsexceptions import NSNitroNserrAlreadyRevkd
from nsexceptions import NSNitroNserrLoadPkey
from nsexceptions import NSNitroNserrCertpkeyNeeded
from nsexceptions import NSNitroNserrPkcs12Needed
from nsexceptions import NSNitroNserrErrFileexists
from nsexceptions import NSNitroNserrFipskeyKeyfileOption
from nsexceptions import NSNitroNserrOutfilelenbig
from nsexceptions import NSNitroNserrSslDefpath
from nsexceptions import NSNitroNserrSslCrlDefpath
from nsexceptions import NSNitroNserrSslDeflocation
from nsexceptions import NSNitroNserrDhreqd
from nsexceptions import NSNitroNserrSslCrlDeflocation
from nsexceptions import NSNitroNserrSslNofipsKey
from nsexceptions import NSNitroNserrSslImproperSerialfile
from nsexceptions import NSNitroNserrSslSerialNumRevoked
from nsexceptions import NSNitroNserrSslMaxrsakeysize
from nsexceptions import NSNitroNserrSslMustbepem
from nsexceptions import NSNitroNserrSslCantbepem
from nsexceptions import NSNitroNserrSslBadLabel
from nsexceptions import NSNitroNserrBadDnsOption
from nsexceptions import NSNitroNserrDnsBadCachetype
from nsexceptions import NSNitroNserrDnsNotavail
from nsexceptions import NSNitroNserrDnsBadVstype
from nsexceptions import NSNitroNserrGslbSitelkupFailed
from nsexceptions import NSNitroNserrNoarec
from nsexceptions import NSNitroNserrInvalttl
from nsexceptions import NSNitroNserrCnameexists
from nsexceptions import NSNitroNserrInvalSvcoption
from nsexceptions import NSNitroNserrGslbbindExists
from nsexceptions import NSNitroNserrNotLocalremote
from nsexceptions import NSNitroNserrCountMismatch
from nsexceptions import NSNitroNserrIpMismatch
from nsexceptions import NSNitroNserrSvcipRepeat
from nsexceptions import NSNitroNserrNotRemote
from nsexceptions import NSNitroNserrNotLocal
from nsexceptions import NSNitroNserrProxyRec
from nsexceptions import NSNitroNserrNoproxyArec
from nsexceptions import NSNitroNserrSvcGslbbindExists
from nsexceptions import NSNitroNserrSvctypemismatch
from nsexceptions import NSNitroNserrInvalidPubipOption
from nsexceptions import NSNitroNserrInvalNameSyntax
from nsexceptions import NSNitroNserrGslbBackup
from nsexceptions import NSNitroNserrIsBackup
from nsexceptions import NSNitroNserrGslbHasBackup
from nsexceptions import NSNitroNserrGslbRequiresIndependentBackup
from nsexceptions import NSNitroNserrGslbNoqualifier
from nsexceptions import NSNitroNserrGslbNoname
from nsexceptions import NSNitroNserrGslbCustomNospace
from nsexceptions import NSNitroNserrGslbStaticNospace
from nsexceptions import NSNitroNserrGslbsitenameExists
from nsexceptions import NSNitroNserrGslbsiteipExists
from nsexceptions import NSNitroNserrNoGslbsite
from nsexceptions import NSNitroNserrLocalExists
from nsexceptions import NSNitroNserrNoGslbsvc
from nsexceptions import NSNitroNserrNoGslbvip
from nsexceptions import NSNitroNserrNoDmn
from nsexceptions import NSNitroNserrDmnNotbound
from nsexceptions import NSNitroNserrGslbdomainBound
from nsexceptions import NSNitroNserrNotGslbent
from nsexceptions import NSNitroNserrGslbdomainPerm
from nsexceptions import NSNitroNserrGslbMaxqual
from nsexceptions import NSNitroNserrGslbMaxloclength
from nsexceptions import NSNitroNserrGslbvipPerm
from nsexceptions import NSNitroNserrGslbsvcPerm
from nsexceptions import NSNitroNserrGslbMaxsites
from nsexceptions import NSNitroNserrGslbQualtoolong
from nsexceptions import NSNitroNserrGslbPersistidexists
from nsexceptions import NSNitroNserrGslbInvldLdnstoIntvl
from nsexceptions import NSNitroNserrVipBackupIsgslb
from nsexceptions import NSNitroNserrGslbPubipPubportExists
from nsexceptions import NSNitroNserrGslblocalsvcEnadisNotallowed
from nsexceptions import NSNitroNserrGslblocalsvrEnadisNotallowed
from nsexceptions import NSNitroNserrInvalidPersistid
from nsexceptions import NSNitroNserrPermPersistid
from nsexceptions import NSNitroNserrInvalidLocalsiteip
from nsexceptions import NSNitroNserrInvalidRemotesiteip
from nsexceptions import NSNitroNserrInvalidSitetype
from nsexceptions import NSNitroNserrInvalidBackupip
from nsexceptions import NSNitroNserrGslbvipMaxsvc
from nsexceptions import NSNitroNserrInvalidJitter
from nsexceptions import NSNitroNserrGslblocsvcDisNotallowd
from nsexceptions import NSNitroNserrDummybkupNotallowd
from nsexceptions import NSNitroNserrGslbsvcBindNotallowd
from nsexceptions import NSNitroNserrNsmapVersion
from nsexceptions import NSNitroNserrNsmapFormat
from nsexceptions import NSNitroNserrNsmapEof
from nsexceptions import NSNitroNserrNsmapParse
from nsexceptions import NSNitroNserrNsmapRead
from nsexceptions import NSNitroNserrNsmapWrite
from nsexceptions import NSNitroNserrNsmapIoctl
from nsexceptions import NSNitroNserrNsmapOutputfile
from nsexceptions import NSNitroNserrNsmapInputfile
from nsexceptions import NSNitroNserrNsmapRequiredField
from nsexceptions import NSNitroNserrNsmapDbfile
from nsexceptions import NSNitroNserrNsmapDbinsert
from nsexceptions import NSNitroNserrNsmapDbsearch
from nsexceptions import NSNitroNserrGslbproxmLicenceAbsent
from nsexceptions import NSNitroNserrGslbSitepersistenceHttponly
from nsexceptions import NSNitroNserrGslbNositepfx
from nsexceptions import NSNitroNserrGslbSiteprefixSize
from nsexceptions import NSNitroNserrGslbSitedomainSize
from nsexceptions import NSNitroNserrGslbSitedomainSyntax
from nsexceptions import NSNitroNserrGslbSitedomainRefers
from nsexceptions import NSNitroNserrGslbdomainRefers
from nsexceptions import NSNitroNserrGslbArecordExists
from nsexceptions import NSNitroNserrGslbSitecookieTimeoutRange
from nsexceptions import NSNitroNserrGslbdomainSyntax
from nsexceptions import NSNitroNserrGslbSoPerm
from nsexceptions import NSNitroNserrGslbDeprcookietout
from nsexceptions import NSNitroNserrDnsNamesvrSyntax
from nsexceptions import NSNitroNserrDnsOrigsvrSyntax
from nsexceptions import NSNitroNserrDnsContactSyntax
from nsexceptions import NSNitroNserrDnsMxSyntax
from nsexceptions import NSNitroNserrDnsCnameSyntax
from nsexceptions import NSNitroNserrDnsAliasSyntax
from nsexceptions import NSNitroNserrGslbNolocalvip
from nsexceptions import NSNitroNserrGslbLocalsvcexists
from nsexceptions import NSNitroNserrGslblocalsvcPerm
from nsexceptions import NSNitroNserrDnsInvalRevdomnameSyntax
from nsexceptions import NSNitroNserrDnsAliasrec
from nsexceptions import NSNitroNserrGslblocsvcDelayedcleanNotallowd
from nsexceptions import NSNitroNserrNoBkpVip
from nsexceptions import NSNitroNserrGslbNosuchLdnsentry
from nsexceptions import NSNitroNserrMaxDnsView
from nsexceptions import NSNitroNserrGslbSiteIpExists
from nsexceptions import NSNitroNserrGslbLastMip
from nsexceptions import NSNitroNserrRmGslbSite
from nsexceptions import NSNitroNserrGslbIprmLastMip
from nsexceptions import NSNitroNserrGslbSvcPubPortErr
from nsexceptions import NSNitroNserrRecHasRef
from nsexceptions import NSNitroNserrDnsViewRef
from nsexceptions import NSNitroNserrGslbSitePersistenceMatch
from nsexceptions import NSNitroNserrGslbSitePersistenceConflicts
from nsexceptions import NSNitroNserrDnsPolicyInval
from nsexceptions import NSNitroNserrGslbvipCnameMismatch
from nsexceptions import NSNitroNserrGslbvipCnameUnsupportedLbmethods
from nsexceptions import NSNitroNserrGslbServiceMonNoipport
from nsexceptions import NSNitroNserrGslbServiceMonSetNoipport
from nsexceptions import NSNitroNserrGslbCnameServiceSet
from nsexceptions import NSNitroNserrGslbCnameVserverSet
from nsexceptions import NSNitroNserrGslbvipCnameUnsupportedBkupLbmethods
from nsexceptions import NSNitroNserrGslbvipCnameUnsupportedEdr
from nsexceptions import NSNitroNserrGslbvipCnameUnsupportedMir
from nsexceptions import NSNitroNserrGslbsvcViewNexist
from nsexceptions import NSNitroNserrDnsTtlMoreThanMaxAllowed
from nsexceptions import NSNitroNserrGslbLbMaxsites
from nsexceptions import NSNitroNserrGslbHaschildren
from nsexceptions import NSNitroNserrGslbParentischild
from nsexceptions import NSNitroNserrMaxRltSelectors
from nsexceptions import NSNitroNserrMaxRltIdentifers
from nsexceptions import NSNitroNserrNoSuchSelector
from nsexceptions import NSNitroNserrNoSuchIdentifier
from nsexceptions import NSNitroNserrRltTimesliceInvalidVal
from nsexceptions import NSNitroNserrIllegalSubnetMask
from nsexceptions import NSNitroNserrRltSelectorInuse
from nsexceptions import NSNitroNserrRltIdentifierInuse
from nsexceptions import NSNitroNserrRltSelectorCannotChangeAttribType
from nsexceptions import NSNitroNserrGslbIgnTrigmon
from nsexceptions import NSNitroNserrRltSelectorNotMoreThan2Ipv6Exp
from nsexceptions import NSNitroNserrRepeatedMonitors
from nsexceptions import NSNitroNserrAllMonitorsDisabled
from nsexceptions import NSNitroNserrGslbAaaarecordExists
from nsexceptions import NSNitroNserrGslbvipHeterogeneousServiceIpversion
from nsexceptions import NSNitroNserrViewipIpv6
from nsexceptions import NSNitroNserrBackupipIpv6
from nsexceptions import NSNitroNserrBackupVipMismatch
from nsexceptions import NSNitroNserrGslbDomainConversion
from nsexceptions import NSNitroNserrGslbIpv4Backupip
from nsexceptions import NSNitroNserrRltCannotAddSelector
from nsexceptions import NSNitroNserrRltSelConflictingAttributes
from nsexceptions import NSNitroNserrGslbvipCnameBackupip
from nsexceptions import NSNitroNserrGslbHeterogeneousSiteip
from nsexceptions import NSNitroNserrGslbUnused1
from nsexceptions import NSNitroNserrGslbUnused2
from nsexceptions import NSNitroNserrAaaaRecordExists
from nsexceptions import NSNitroNserrGslbRectypeService
from nsexceptions import NSNitroNserrGslbRectypeDomain
from nsexceptions import NSNitroNserrGslbRectypeBackupVip
from nsexceptions import NSNitroNserrGslbBkpvipRectype
from nsexceptions import NSNitroNserrGslbUnused3
from nsexceptions import NSNitroNserrBackupipIpv4
from nsexceptions import NSNitroNserrGslbIpv6Backupip
from nsexceptions import NSNitroNserrGslbDbReqTooBig
from nsexceptions import NSNitroNserrGslbDbQueueMaxed
from nsexceptions import NSNitroNserrGslbDbServer
from nsexceptions import NSNitroNserrGslbDbTimeout
from nsexceptions import NSNitroNserrGslbDbClosed
from nsexceptions import NSNitroNserrGslbCoordinates
from nsexceptions import NSNitroNserrInvalidIpv6Prefixlen
from nsexceptions import NSNitroNserrGslbdomainCanmeRecordExists
from nsexceptions import NSNitroNserrGslbdomainAaaaCnameExists
from nsexceptions import NSNitroNserrGslbNonParentRemotesite
from nsexceptions import NSNitroNserrZoneExists
from nsexceptions import NSNitroNserrInvalKeyflags
from nsexceptions import NSNitroNserrDnskeyNonexists
from nsexceptions import NSNitroNserrNorecsInZone
from nsexceptions import NSNitroNserrSignfailed
from nsexceptions import NSNitroNserrDigestinitFailed
from nsexceptions import NSNitroNserrDigestupdateFailed
from nsexceptions import NSNitroNserrKeyexists
from nsexceptions import NSNitroNserrNopasvkeys
from nsexceptions import NSNitroNserrDnsMaxkeysize
from nsexceptions import NSNitroNserrNodataToSign
from nsexceptions import NSNitroNserrCnameSiteNotexists
from nsexceptions import NSNitroNserrDnsNosoaNons
from nsexceptions import NSNitroNserrDnsProxyZone
from nsexceptions import NSNitroNserrNoactvkeys
from nsexceptions import NSNitroNserrNotifyperiod
from nsexceptions import NSNitroNserrLoadPubkey
from nsexceptions import NSNitroNserrDnskeygenUnsupportedAlgo
from nsexceptions import NSNitroNserrDnskeygenErrPubfileOpen
from nsexceptions import NSNitroNserrDnskeygenErrPrivfileOpen
from nsexceptions import NSNitroNserrDnskeygenErrDsfileOpen
from nsexceptions import NSNitroNserrGslbOptNotsupported
from nsexceptions import NSNitroNserrGslbGfsNotSupported
from nsexceptions import NSNitroNserrNsmapImportfile
from nsexceptions import NSNitroNserrDnsCnameloop
from nsexceptions import NSNitroNscfgInfo
from nsexceptions import NSNitroNscsInfo
from nsexceptions import NSNitroNscsprobeInfo
from nsexceptions import NSNitroNsappprobeInfo
from nsexceptions import NSNitroNscfgMpInfo
from nsexceptions import NSNitroNserrNointranetip
from nsexceptions import NSNitroNserrAlreadylogedin
from nsexceptions import NSNitroNserrUrlinuse
from nsexceptions import NSNitroNserrVpnappinuse
from nsexceptions import NSNitroNserrNotsuppTransIntercpt
from nsexceptions import NSNitroNserrNotsuppProtUdp
from nsexceptions import NSNitroNserrDefaultcmdplcy
from nsexceptions import NSNitroNserrClntCertReqd
from nsexceptions import NSNitroNserrInvalCertfield
from nsexceptions import NSNitroNserrVpnappProxyIprange
from nsexceptions import NSNitroNserrVpnappProxyNetmask
from nsexceptions import NSNitroNserrVpnappProxyDstportRange
from nsexceptions import NSNitroNserrVpnappProxyProtocol
from nsexceptions import NSNitroNserrVpnappProxyHostname
from nsexceptions import NSNitroNserrVpnappTransSrcip
from nsexceptions import NSNitroNserrVpnappTransSrcport
from nsexceptions import NSNitroNserrVpnappNoInterceptionType
from nsexceptions import NSNitroNserrVpnappCliappPort
from nsexceptions import NSNitroNserrVpnappCliappProto
from nsexceptions import NSNitroNserrVpnappProxyCliapp
from nsexceptions import NSNitroNserrVpnappMissingProto
from nsexceptions import NSNitroNserrVpnappMissingArg
from nsexceptions import NSNitroNserrVpnappTooManyArg
from nsexceptions import NSNitroNserrFsAuthfail
from nsexceptions import NSNitroNserrNsipv6notpresent
from nsexceptions import NSNitroNserrRemoveSession
from nsexceptions import NSNitroNserrStawiExist
from nsexceptions import NSNitroNserrInvalidSsoAction
from nsexceptions import NSNitroNserrInvalidTmtrafficAction
from nsexceptions import NSNitroNserrInvalfsso
from nsexceptions import NSNitroNserrInvalidurl
from nsexceptions import NSNitroNserrInvalidpol
from nsexceptions import NSNitroNserrNopol
from nsexceptions import NSNitroNserrRuleurl
from nsexceptions import NSNitroNserrDelmc
from nsexceptions import NSNitroNserrAcp
from nsexceptions import NSNitroNserrAcs
from nsexceptions import NSNitroNserrNosetCexp
from nsexceptions import NSNitroNserrCexpDepth
from nsexceptions import NSNitroNserrNovpnapp
from nsexceptions import NSNitroNserrNosetCse
from nsexceptions import NSNitroNserrInvalPolname
from nsexceptions import NSNitroNserrUnbindInvalidpol
from nsexceptions import NSNitroNserrExceedMaxPolLimit
from nsexceptions import NSNitroNserrInternalPiError
from nsexceptions import NSNitroNserrInterfacebound
from nsexceptions import NSNitroNserrIfaceNoUnbind
from nsexceptions import NSNitroNserrIfaceMaxVlans
from nsexceptions import NSNitroNserrMonitorInterval
from nsexceptions import NSNitroNserrMonitorDestip
from nsexceptions import NSNitroNserrMonitorCodes
from nsexceptions import NSNitroNserrMonitorRef
from nsexceptions import NSNitroNserrMonitorBuiltin
from nsexceptions import NSNitroNserrMonitorBound
from nsexceptions import NSNitroNserrMonitorType
from nsexceptions import NSNitroNserrMonitorLocal
from nsexceptions import NSNitroNserrTimeoutRange
from nsexceptions import NSNitroNserrInvalidhashlen
from nsexceptions import NSNitroNserrNotauthorized
from nsexceptions import NSNitroNserrMonitorDefault
from nsexceptions import NSNitroNserrMonitorLdnsAddPerm
from nsexceptions import NSNitroNserrMonitorLdnsBindPerm
from nsexceptions import NSNitroNserrBackupLoop
from nsexceptions import NSNitroNserrSecureUdp
from nsexceptions import NSNitroNserrMonitorWrongType
from nsexceptions import NSNitroNserrLrtmPerm
from nsexceptions import NSNitroNserrMonitorScriptname
from nsexceptions import NSNitroNserrMonitorDispatcherip
from nsexceptions import NSNitroNserrMonitorUserperm
from nsexceptions import NSNitroNserrMonitorNocodes
from nsexceptions import NSNitroNserrInvalMon
from nsexceptions import NSNitroNserrTypeExists
from nsexceptions import NSNitroNserrMonitorUnbindDefault
from nsexceptions import NSNitroNserrMonitorBindDefault
from nsexceptions import NSNitroNserrMonitorDisableDefault
from nsexceptions import NSNitroNserrDrtmPerm
from nsexceptions import NSNitroNserrMonDtrmDeviation
from nsexceptions import NSNitroNserrMonitorInvalidValue
from nsexceptions import NSNitroNserrMonitorNotBound
from nsexceptions import NSNitroNserrInvalidMonitor
from nsexceptions import NSNitroNserrMonitorNoSuchipaddr
from nsexceptions import NSNitroNserrMonitorScriptArgSize
from nsexceptions import NSNitroNserrMetrictableNoent
from nsexceptions import NSNitroNserrMetrictableExist
from nsexceptions import NSNitroNserrDelMetrictablePermanent
from nsexceptions import NSNitroNserrMaxMetricBinding
from nsexceptions import NSNitroNserrMetricNoent
from nsexceptions import NSNitroNserrMetricExists
from nsexceptions import NSNitroNserrOidExist
from nsexceptions import NSNitroNserrSnmpOidInval
from nsexceptions import NSNitroNserrMetrictableRdonly
from nsexceptions import NSNitroNserrThresholdZero
from nsexceptions import NSNitroNserrLdapMonitorIncomplete
from nsexceptions import NSNitroNserrMysqlMonitorIncomplete
from nsexceptions import NSNitroNserrPop3MonitorIncomplete
from nsexceptions import NSNitroNserrNntpMonitorIncomplete
from nsexceptions import NSNitroNserrFtpextendedMonitorIncomplete
from nsexceptions import NSNitroNserrSnmpMonitorIncomplete
from nsexceptions import NSNitroNserrCitrixXmlService
from nsexceptions import NSNitroNserrCitrixWebInterface
from nsexceptions import NSNitroNserrLdnsMonCantDisable
from nsexceptions import NSNitroNserrResRetryOnIpSvr
from nsexceptions import NSNitroNserrIpOnDbsSvr
from nsexceptions import NSNitroNserrMonitorAlertretries
from nsexceptions import NSNitroNserrMonitorFailureretries
from nsexceptions import NSNitroNserrMonitorAlertfailureretries
from nsexceptions import NSNitroNserrMonitorIp
from nsexceptions import NSNitroNserrMonitorSubnet
from nsexceptions import NSNitroNserrMonitorStatic
from nsexceptions import NSNitroNserrTosidNotSet
from nsexceptions import NSNitroNserrFailureretriesNotSupported
from nsexceptions import NSNitroNserrSuccessretriesNotSupported
from nsexceptions import NSNitroNserrSetvsInvalMysqlparams
from nsexceptions import NSNitroNserrSetvsInvalProtocolParams
from nsexceptions import NSNitroNserrSetvsInvalProtocolsParams
from nsexceptions import NSNitroNserrDdcValidateCredRequired
from nsexceptions import NSNitroNserrCitrixWiExtendedMonitorIncomplete
from nsexceptions import NSNitroNserrSvcporttype
from nsexceptions import NSNitroNserrVipInGroup
from nsexceptions import NSNitroNserrUnsupportedBkp
from nsexceptions import NSNitroNserrNonhttpsslVipingrp
from nsexceptions import NSNitroNserrNonhttpVipingrp
from nsexceptions import NSNitroNserrUseProperRmCmd
from nsexceptions import NSNitroNserrLbmethodNotSupported
from nsexceptions import NSNitroNserrPersistenceNotSupported
from nsexceptions import NSNitroNserrVserverParameters
from nsexceptions import NSNitroNserrServiceParameters
from nsexceptions import NSNitroNserrLbvipDelete
from nsexceptions import NSNitroNserrCachepolicyRespactionInval
from nsexceptions import NSNitroNserrCachelicenseFailed
from nsexceptions import NSNitroNserrLbvipMultiroutes
from nsexceptions import NSNitroNserrLbmacInval
from nsexceptions import NSNitroNserrCachestatsObjNotpresent
from nsexceptions import NSNitroNserrCachepolicyNotactive
from nsexceptions import NSNitroNserrCacheBuiltinsNotSourced
from nsexceptions import NSNitroNserrCachepolicyPriorityInval
from nsexceptions import NSNitroNserrRoute6DefaultOnly
from nsexceptions import NSNitroNserrRoute6DefaultExists
from nsexceptions import NSNitroNserrRoute6InvalidGateway
from nsexceptions import NSNitroNserrRoute6Max
from nsexceptions import NSNitroNserrRoute6NotExist
from nsexceptions import NSNitroNserrIpv6InvalidAddr
from nsexceptions import NSNitroNserrLbvipIpv6tov4
from nsexceptions import NSNitroNserrIpv6Nsiptovip
from nsexceptions import NSNitroNserrIpv6Viptonsip
from nsexceptions import NSNitroNserrIpv6Scope
from nsexceptions import NSNitroNserrLbvipIpv4tov6
from nsexceptions import NSNitroNserrIpv6Linklocaltovip
from nsexceptions import NSNitroNserrIpv6Mapiponnsip
from nsexceptions import NSNitroNserrSecureipportaddrinuse
from nsexceptions import NSNitroNserrIpv6InvalidPrefix
from nsexceptions import NSNitroNserrNd6LinklocalVlan
from nsexceptions import NSNitroNserrNd6VlanIntf
from nsexceptions import NSNitroNserrPersistTimeoutToDefault
from nsexceptions import NSNitroNserrLbGroupNotExist
from nsexceptions import NSNitroNserrLbVserverAlreadyBound
from nsexceptions import NSNitroNserrNameSvrExists
from nsexceptions import NSNitroNserrNameSvrIdnsNempty
from nsexceptions import NSNitroNserrNameSvrIvalpolicy
from nsexceptions import NSNitroNserrNameSvrIvalproto
from nsexceptions import NSNitroNserrNameSvrAddNexistVip
from nsexceptions import NSNitroNserrNameSvrNexist
from nsexceptions import NSNitroNserrNameSvrIdnsPerm
from nsexceptions import NSNitroNserrNameSvrIpExists
from nsexceptions import NSNitroNserrErrAaaLicense
from nsexceptions import NSNitroNserrUsrNointraip
from nsexceptions import NSNitroNserrUsrNotconfigured
from nsexceptions import NSNitroNserrInvalAaaGrp
from nsexceptions import NSNitroNserrInvalCombnation
from nsexceptions import NSNitroNserrInvalMipIip
from nsexceptions import NSNitroNserrInvalMipoffIipoff
from nsexceptions import NSNitroNserrUserexist
from nsexceptions import NSNitroNserrGroupexist
from nsexceptions import NSNitroNserrUseralreadybound
from nsexceptions import NSNitroNserrUsernotbound
from nsexceptions import NSNitroNserrEntitynotbound
from nsexceptions import NSNitroNserrGroupnotexist
from nsexceptions import NSNitroNserrInvalidloglevel
from nsexceptions import NSNitroNserrDhMisconfig
from nsexceptions import NSNitroNserrDhIpport
from nsexceptions import NSNitroNserrDhinuse
from nsexceptions import NSNitroNserrInvalAaaglobalPoltype
from nsexceptions import NSNitroNserrNoIp
from nsexceptions import NSNitroNserrAaatmLic
from nsexceptions import NSNitroNserrAaatmDisabled
from nsexceptions import NSNitroNserrNoAuthHost
from nsexceptions import NSNitroNserrAuthOn
from nsexceptions import NSNitroNserrKillpending
from nsexceptions import NSNitroNserrAaatmNoAuthVs
from nsexceptions import NSNitroNserrAaatm401authOn
from nsexceptions import NSNitroNserrUnauthrzed
from nsexceptions import NSNitroNserrKillInprogress
from nsexceptions import NSNitroNserrWiFrmNotexist
from nsexceptions import NSNitroNserrWiFrmLast
from nsexceptions import NSNitroNserrWiNotinst
from nsexceptions import NSNitroNserrWiGenfailed
from nsexceptions import NSNitroNserrWiSiteExist
from nsexceptions import NSNitroNserrWiSiteNotexist
from nsexceptions import NSNitroNserrWiSiteInvalAgurl
from nsexceptions import NSNitroNserrWiSiteInvalStaurl
from nsexceptions import NSNitroNserrWiSiteOnlyMpx
from nsexceptions import NSNitroNserrWiInstfailed
from nsexceptions import NSNitroNserrWiMaxsiteExcd
from nsexceptions import NSNitroNserrWiStawithoutagurl
from nsexceptions import NSNitroNserrWiAgurlwithoutsta
from nsexceptions import NSNitroNserrWiRelwithoutagurl
from nsexceptions import NSNitroNserrWiAuthwithoutagurl
from nsexceptions import NSNitroNserrWiTwotktwithoutrel
from nsexceptions import NSNitroNserrWiTwotktwithoutsecsta
from nsexceptions import NSNitroNserrWiSecstasame
from nsexceptions import NSNitroNserrWiLicense
from nsexceptions import NSNitroNserrWiSecstawithoutsta
from nsexceptions import NSNitroNserrAuthNegotiate
from nsexceptions import NSNitroNserrWiInstsitesreduced
from nsexceptions import NSNitroNserrWiIncompatibleauthpoint
from nsexceptions import NSNitroNserrWiSiteWithinSite
from nsexceptions import NSNitroNserrTmInvalidPersConfig
from nsexceptions import NSNitroNserrRwActInval
from nsexceptions import NSNitroNserrRwUndefactInval
from nsexceptions import NSNitroNserrActflowmismatch
from nsexceptions import NSNitroNserrRonlyTarExpr
from nsexceptions import NSNitroNserrPatsetBindfail
from nsexceptions import NSNitroNserrPatsetUnbindfail
from nsexceptions import NSNitroNserrPatsetNotpresent
from nsexceptions import NSNitroNserrRspActInval
from nsexceptions import NSNitroNserrRspPolicyFlowtypeReq
from nsexceptions import NSNitroNserrTarFlowtypeNres
from nsexceptions import NSNitroNserrRspConfigLock
from nsexceptions import NSNitroNserrRspActMustBeNoop
from nsexceptions import NSNitroNserrPatsetInvalidRegex
from nsexceptions import NSNitroNserrPatsetBindfailDupIndex
from nsexceptions import NSNitroNserrPatsetBindfailIndexNotGiven
from nsexceptions import NSNitroNserrPatsetBindfailIndexNotRequired
from nsexceptions import NSNitroNserrPatsetBindfailPatlenLtWuMinlen
from nsexceptions import NSNitroNserrTargetNotAllowedInRule
from nsexceptions import NSNitroNserrRwTargetNotAllowedInStrbuilder
from nsexceptions import NSNitroNserrPitInval
from nsexceptions import NSNitroNserrInvalInvokepoint
from nsexceptions import NSNitroNserrPitMaxPacket
from nsexceptions import NSNitroNserrRefineSearchInvalid
from nsexceptions import NSNitroNserrExtendInvalid
from nsexceptions import NSNitroNserrNonExtendExpr
from nsexceptions import NSNitroNserrExtendInvalPirl
from nsexceptions import NSNitroNserrInvalTarExpr
from nsexceptions import NSNitroNserrInvalPatternSearchSet
from nsexceptions import NSNitroNserrInvalSearchArgs
from nsexceptions import NSNitroNserrRspActMustBeResetDrop
from nsexceptions import NSNitroNserrInvalSearchSyntax
from nsexceptions import NSNitroNserrInvalSearchXpathSyntax
from nsexceptions import NSNitroNserrInvalSearchPatsetSyntax
from nsexceptions import NSNitroNserrInvalSearchRegexSyntax
from nsexceptions import NSNitroNserrRwReqBodyNotAllowed
from nsexceptions import NSNitroNserrRenameNotsupported
from nsexceptions import NSNitroNserrEntityRemovalNotallowed
from nsexceptions import NSNitroNserrPiEntityExists
from nsexceptions import NSNitroNserrIncompatibleCalloutChange
from nsexceptions import NSNitroNserrStringmapNotpresent
from nsexceptions import NSNitroNserrUrltransMaxEntities
from nsexceptions import NSNitroNserrUrltransInvalProfile
from nsexceptions import NSNitroNserrUrltransActionInuse
from nsexceptions import NSNitroNserrUrltransPriorityExists
from nsexceptions import NSNitroNserrUrltransReqPcreErr
from nsexceptions import NSNitroNserrUrltransRespPcreErr
from nsexceptions import NSNitroNserrUrltransReqIntoErr
from nsexceptions import NSNitroNserrUrltransRespIntoErr
from nsexceptions import NSNitroNserrUrltransCookieIntoErr
from nsexceptions import NSNitroNserrUrltransCookiePcreErr
from nsexceptions import NSNitroNserrUrltransTooManyBackrefs
from nsexceptions import NSNitroNserrUrltransMissingFrom
from nsexceptions import NSNitroNserrPiLongvsvrname
from nsexceptions import NSNitroNserrPiPriorityExists
from nsexceptions import NSNitroNserrInvalpiexpr
from nsexceptions import NSNitroNserrInvalintop
from nsexceptions import NSNitroNserrInvalcompare
from nsexceptions import NSNitroNserrInvalboolop
from nsexceptions import NSNitroNserrArgneg
from nsexceptions import NSNitroNserrArgexceed
from nsexceptions import NSNitroNserrArgzero
from nsexceptions import NSNitroNserrMaxheader
from nsexceptions import NSNitroNserrInvalpicexpr
from nsexceptions import NSNitroNserrCexprlimit
from nsexceptions import NSNitroNserrExprlimit
from nsexceptions import NSNitroNserrSexprlimit
from nsexceptions import NSNitroNserrInvalpisexpr
from nsexceptions import NSNitroNserrNobidi
from nsexceptions import NSNitroNserrNolab
from nsexceptions import NSNitroNserrInternalLabelRm
from nsexceptions import NSNitroNserrPolicyFlowtypeNone
from nsexceptions import NSNitroNserrInvalPriority
from nsexceptions import NSNitroNserrNumericexpr
from nsexceptions import NSNitroNserrBoolexpr
from nsexceptions import NSNitroNserrNotbound
from nsexceptions import NSNitroNserrPolicyInuse
from nsexceptions import NSNitroNserrPolicySetNotallowed
from nsexceptions import NSNitroNserrInvalidBind
from nsexceptions import NSNitroNserrUseInvokeResult
from nsexceptions import NSNitroNserrInvalUnbind
from nsexceptions import NSNitroNserrRegexInvalid
from nsexceptions import NSNitroNserrRegexBackref
from nsexceptions import NSNitroNserrRegexRecursive
from nsexceptions import NSNitroNserrPixlExprUnsafe
from nsexceptions import NSNitroNserrPiActionMaxRefReached
from nsexceptions import NSNitroNserrPiInvalidUnset
from nsexceptions import NSNitroNserrEmptyString
from nsexceptions import NSNitroNserrInvalBtwArgs
from nsexceptions import NSNitroNserrInvalArgSpecified
from nsexceptions import NSNitroNserrInvalArgCspl
from nsexceptions import NSNitroNserrFlowtypeNotApplicable
from nsexceptions import NSNitroNserrInvalArgSpecifiedCs
from nsexceptions import NSNitroNserrInvalGotoexprCs
from nsexceptions import NSNitroNserrRebindFailed
from nsexceptions import NSNitroNserrSecondBind
from nsexceptions import NSNitroNserrNonhttpVs
from nsexceptions import NSNitroNserrInvalXpathExpr
from nsexceptions import NSNitroNserrXpathExprNotSupported
from nsexceptions import NSNitroNserrTargetInval
from nsexceptions import NSNitroNserrNonRespHttpVsList
from nsexceptions import NSNitroNserrInvalVserverBind
from nsexceptions import NSNitroNserrAppFreedNsb
from nsexceptions import NSNitroNserrMultBindInval
from nsexceptions import NSNitroNserrInvalidKeyvalue
from nsexceptions import NSNitroNserrAsNostarturl
from nsexceptions import NSNitroNserrAsExistStarturl
from nsexceptions import NSNitroNserrAsNodenyurl
from nsexceptions import NSNitroNserrAsExistDenyurl
from nsexceptions import NSNitroNserrAsNocookieconsistency
from nsexceptions import NSNitroNserrAsExistCookieconsistency
from nsexceptions import NSNitroNserrAsNofieldconsistency
from nsexceptions import NSNitroNserrAsExistFieldconsistency
from nsexceptions import NSNitroNserrAsNoxss
from nsexceptions import NSNitroNserrAsExistXss
from nsexceptions import NSNitroNserrAsNosql
from nsexceptions import NSNitroNserrAsExistSql
from nsexceptions import NSNitroNserrAsNofieldformat
from nsexceptions import NSNitroNserrAsExistFieldformat
from nsexceptions import NSNitroNserrAsNoobjectexpression
from nsexceptions import NSNitroNserrAsExistObjectexpression
from nsexceptions import NSNitroNserrAsNofieldtype
from nsexceptions import NSNitroNserrAsBadActionStarturl
from nsexceptions import NSNitroNserrAsBadActionDenyurl
from nsexceptions import NSNitroNserrAsBadActionCookieconsistency
from nsexceptions import NSNitroNserrAsBadActionFieldconsistency
from nsexceptions import NSNitroNserrAsBadActionXss
from nsexceptions import NSNitroNserrAsBadActionSql
from nsexceptions import NSNitroNserrAsBadActionFieldformat
from nsexceptions import NSNitroNserrAsBadActionObjectexpression
from nsexceptions import NSNitroNserrAsBadActionBufferoverflow
from nsexceptions import NSNitroNserrAsBadActionCcard
from nsexceptions import NSNitroNserrAsFieldformatMinGtMax
from nsexceptions import NSNitroNserrAsFieldtypeBadNameLen
from nsexceptions import NSNitroNserrAsBadCommentLen
from nsexceptions import NSNitroNserrAsFieldtypeBadRegexLen
from nsexceptions import NSNitroNserrAsSecurityCheckRequired
from nsexceptions import NSNitroNserrAsFieldtypeBuiltin
from nsexceptions import NSNitroNserrAsMaxEntities
from nsexceptions import NSNitroNserrAsBadDefaultCharset
from nsexceptions import NSNitroNserrAsBadCookieconsistencyName
from nsexceptions import NSNitroNserrAsBadErrorurl
from nsexceptions import NSNitroNserrAsBadEncodingUrl
from nsexceptions import NSNitroNserrAsBadEncodingFieldname
from nsexceptions import NSNitroNserrAsBadEncodingCookiename
from nsexceptions import NSNitroNserrAsBadEncodingObjectexpressionName
from nsexceptions import NSNitroNserrAsBadEncodingExpression
from nsexceptions import NSNitroNserrAsBadEncodingRegex
from nsexceptions import NSNitroNserrAsModifiedUrl
from nsexceptions import NSNitroNserrAsModifiedObjectexpression
from nsexceptions import NSNitroNserrAsCffieldBadFieldnameLen
from nsexceptions import NSNitroNserrAsCffieldBadUrlLen
from nsexceptions import NSNitroNserrAsNocffield
from nsexceptions import NSNitroNserrAsBadCffName
from nsexceptions import NSNitroNserrAsBadCffUrl
from nsexceptions import NSNitroNserrAsCffDup
from nsexceptions import NSNitroNserrAsBadActionXdos
from nsexceptions import NSNitroNserrAsExistXmlDosUrl
from nsexceptions import NSNitroNserrXmlUrlNotSupported
from nsexceptions import NSNitroNserrAsNoXdosUrl
from nsexceptions import NSNitroNserrAsInvalidXmlDosConf
from nsexceptions import NSNitroNserrAsBadActionXmlSqlinjection
from nsexceptions import NSNitroNserrAsBadActionXmlXss
from nsexceptions import NSNitroNserrAsBadActionXmlWellformedness
from nsexceptions import NSNitroNserrAsBadActionProfileType
from nsexceptions import NSNitroNserrAsModifiedFieldname
from nsexceptions import NSNitroNserrAsBadActionWsi
from nsexceptions import NSNitroNserrAsExistXmlWsiUrl
from nsexceptions import NSNitroNserrAsNoWsiUrl
from nsexceptions import NSNitroNserrAsInvalidXmlWsiConf
from nsexceptions import NSNitroNserrAsObjectnameTooBig
from nsexceptions import NSNitroNserrAsObjectNoExist
from nsexceptions import NSNitroNserrAsServerNameTooBig
from nsexceptions import NSNitroNserrAsObjectNotReadable
from nsexceptions import NSNitroNserrAsNoprofile
from nsexceptions import NSNitroNserrAsBadActionXmlAttachment
from nsexceptions import NSNitroNserrAsBadActionMsgval
from nsexceptions import NSNitroNserrAsExistXmlMsgvalUrl
from nsexceptions import NSNitroNserrAsNoMsgvalUrl
from nsexceptions import NSNitroNserrAsInvalidXmlMsgvalConf
from nsexceptions import NSNitroNserrAsBindXmlMsgvalConf
from nsexceptions import NSNitroNserrAsImportFailed
from nsexceptions import NSNitroNserrAsObjectExist
from nsexceptions import NSNitroNserrAsInvalidOption
from nsexceptions import NSNitroNserrAsRemoveFailed
from nsexceptions import NSNitroNserrAsNoResource
from nsexceptions import NSNitroNserrAsShowFailed
from nsexceptions import NSNitroNserrAsDependencyFailed
from nsexceptions import NSNitroNserrAsCompilationFailed
from nsexceptions import NSNitroNserrInvalidObjectName
from nsexceptions import NSNitroNserrAsImportDownloadFailed
from nsexceptions import NSNitroNserrAsResourceInuse
from nsexceptions import NSNitroNserrAsBadMappingData
from nsexceptions import NSNitroNserrAsProfileChangeHtml
from nsexceptions import NSNitroNserrAsProfileChangeXml
from nsexceptions import NSNitroNserrAsImportAlreadyInprocess
from nsexceptions import NSNitroNserrAsInvalidXmlErrorObject
from nsexceptions import NSNitroNserrAsXmlWellformednessDisabled
from nsexceptions import NSNitroNserrAsIndividualImportLimitExceeded
from nsexceptions import NSNitroNserrAsTotalImportLimitExceeded
from nsexceptions import NSNitroNserrAsLearningBusy
from nsexceptions import NSNitroNserrAsDeprecatedXmlWsiRuleR4003
from nsexceptions import NSNitroNserrAsExistXmlAttachmentUrl
from nsexceptions import NSNitroNserrAsNoXmlAttachmentUrl
from nsexceptions import NSNitroNserrAsBadActionSoapFault
from nsexceptions import NSNitroNserrAsXmlDosValueOutOfRange
from nsexceptions import NSNitroNserrAsXmlMsgvalCliError
from nsexceptions import NSNitroNserrAsInvalidCustomSettingsObject
from nsexceptions import NSNitroNserrAsSessionTimeoutLifetimeConflict
from nsexceptions import NSNitroNserrAsClassicPolicyAlreadyBound
from nsexceptions import NSNitroNserrAsAdvancedPolicyAlreadyBound
from nsexceptions import NSNitroNserrAsCustomSettingsNoInjectionType
from nsexceptions import NSNitroNserrAsNocsrfTag
from nsexceptions import NSNitroNserrAsExistCsrfTag
from nsexceptions import NSNitroNserrAsBadActionCsrfTag
from nsexceptions import NSNitroNserrAsTurningTaggingOffCsrfTagOn
from nsexceptions import NSNitroNserrAsTurningCsrfTagOnTaggingOff
from nsexceptions import NSNitroNserrAsImportLimitLessThanImportDirSize
from nsexceptions import NSNitroNserrAsUnsupportedImportProtocol
from nsexceptions import NSNitroNserrAsUnsupportedExportProtocol
from nsexceptions import NSNitroNserrAsExportFailed
from nsexceptions import NSNitroNserrAsBadLocalFile
from nsexceptions import NSNitroNserrAsInvalidRegexCustomObject
from nsexceptions import NSNitroNserrAsBuiltinInvalidOp
from nsexceptions import NSNitroNserrAsInvalidAdvPolicyState
from nsexceptions import NSNitroNserrAsBuiltinNamesInConf
from nsexceptions import NSNitroNserrAsDefaultProfileIsBypass
from nsexceptions import NSNitroNserrAsNoLearnDenyurl
from nsexceptions import NSNitroNserrAsNoLearnCsrfTag
from nsexceptions import NSNitroNserrAsNoLearnCcard
from nsexceptions import NSNitroNserrAsNoLearnBufferoverflow
from nsexceptions import NSNitroNserrAsNoLearnXmlFormat
from nsexceptions import NSNitroNserrAsNoLearnXmlSqlinjection
from nsexceptions import NSNitroNserrAsNoLearnXmlXss
from nsexceptions import NSNitroNserrAsNoLearnXmlMsgval
from nsexceptions import NSNitroNserrAsNoLearnXmlSoapFault
from nsexceptions import NSNitroNserrAsImportInternalError
from nsexceptions import NSNitroNserrAsNetsvcConnFailed
from nsexceptions import NSNitroNserrAsValidationFailed
from nsexceptions import NSNitroNserrAsCkiTransformDisabled
from nsexceptions import NSNitroNserrAsNoxmlxss
from nsexceptions import NSNitroNserrAsExistXmlxss
from nsexceptions import NSNitroNserrAsNoxmlsql
from nsexceptions import NSNitroNserrAsExistXmlsql
from nsexceptions import NSNitroNserrAsNoEndtag
from nsexceptions import NSNitroNserrAsSigInvalidRuleid
from nsexceptions import NSNitroNserrAsSigInvalidRuleVersion
from nsexceptions import NSNitroNserrAsSigParseError
from nsexceptions import NSNitroNserrAsSigInvalidAttribute
from nsexceptions import NSNitroNserrAsSigMultipleLocations
from nsexceptions import NSNitroNserrAsSigInvalidState
from nsexceptions import NSNitroNserrAsCkiEncryptMethodIsNone
from nsexceptions import NSNitroNserrAsUpdateFailed
from nsexceptions import NSNitroNserrAsObjectNotUsed
from nsexceptions import NSNitroNserrAsSigMultipleUrls
from nsexceptions import NSNitroNserrAsSigMultipleFieldNames
from nsexceptions import NSNitroNserrAsSqlinjectionKeywordInvalidAttribute
from nsexceptions import NSNitroNserrAsSplstringInvalidAttribute
from nsexceptions import NSNitroNserrAsSqlinjectionKeywordLiteralExceedMaxlen
from nsexceptions import NSNitroNserrAsSplstringLiteralExceedMaxlen
from nsexceptions import NSNitroNserrAsXssDeniedPatternInvalidAttribute
from nsexceptions import NSNitroNserrAsXssDeniedPatternExceedMaxlen
from nsexceptions import NSNitroNserrAsXssAllowedPatternInvalidAttribute
from nsexceptions import NSNitroNserrAsXssAllowedPatternExceedMaxlen
from nsexceptions import NSNitroNserrAsSigInternalError
from nsexceptions import NSNitroNserrAsSigNonLiteralFastmatch
from nsexceptions import NSNitroNserrAsSigNegatedLiteralFastmatch
from nsexceptions import NSNitroNserrAsSigMemAllocFailed
from nsexceptions import NSNitroNserrAsSigTooManyPatterns
from nsexceptions import NSNitroNserrAsSigLiteralHexParseError
from nsexceptions import NSNitroNserrAsSigPcreCompileError
from nsexceptions import NSNitroNserrAsSigInvalidFileVersion
from nsexceptions import NSNitroNserrNoSuchProfile
from nsexceptions import NSNitroNserrProfileInUse
from nsexceptions import NSNitroNserrInterfaceBound
from nsexceptions import NSNitroNserrVridInterfaceNotBound
from nsexceptions import NSNitroNserrNoSuchInterface
from nsexceptions import NSNitroNserrInvalthreshold
from nsexceptions import NSNitroNserrWrongthresholds
from nsexceptions import NSNitroNserrInvalidSrcip
from nsexceptions import NSNitroNserrThresholdUnsettable
from nsexceptions import NSNitroNserrTimeUnsettable
from nsexceptions import NSNitroNserrWrongLowThresholds
from nsexceptions import NSNitroNserrPublicip
from nsexceptions import NSNitroNserrPrivateip
from nsexceptions import NSNitroNserrProxyip
from nsexceptions import NSNitroNserrWildcardtcpvip
from nsexceptions import NSNitroNserrWildcardanyvip
from nsexceptions import NSNitroNserrFtpvippresent
from nsexceptions import NSNitroNserrV46Usip
from nsexceptions import NSNitroNserrIncompatibleIp
from nsexceptions import NSNitroNserrTnlNetbridged
from nsexceptions import NSNitroNserrTnlGre
from nsexceptions import NSNitroNserrTnlRipmask
from nsexceptions import NSNitroNserrVlanNetbridged
from nsexceptions import NSNitroNserrMaxNetbridgeTunnel
from nsexceptions import NSNitroNserrTunBound
from nsexceptions import NSNitroNserrSubnetBound
from nsexceptions import NSNitroNserrAppflowInvalidport
from nsexceptions import NSNitroNserrIpfixMaxCollectors
from nsexceptions import NSNitroNserrNoSuchCollector
from nsexceptions import NSNitroNserrAppflowNcoreOnly
from nsexceptions import NSNitroNserrAppflowNonzeroActionRefcount
from nsexceptions import NSNitroNserrAppflowCollectorNameInuse
from nsexceptions import NSNitroNserrAppflowActInval
from nsexceptions import NSNitroNserr1gsfpspeedlimit
from nsexceptions import NSNitroNserr1gsfpduplexlimit
from nsexceptions import NSNitroNserr1gspeedlimit
from nsexceptions import NSNitroNserr1gduplexlimit
from nsexceptions import NSNitroNserr10gspeedlimit
from nsexceptions import NSNitroNserr10gduplexlimit
from nsexceptions import NSNitroNserr10gautoneglimit
from nsexceptions import NSNitroNserr10gspeedonly
from nsexceptions import NSNitroNserrFullduplexonly

__all__ = ['NSNitroError',
           'NSNitroExceptionClassMap',
           'NSNitroNserrNotrunning',
           'NSNitroNserrPerm',
           'NSNitroNserrNoent',
           'NSNitroNserrSrch',
           'NSNitroNserrIntr',
           'NSNitroNserrIo',
           'NSNitroNserrNxio',
           'NSNitroNserr2big',
           'NSNitroNserrNoexec',
           'NSNitroNserrBadf',
           'NSNitroNserrChild',
           'NSNitroNserrDeadlk',
           'NSNitroNserrNomem',
           'NSNitroNserrAcces',
           'NSNitroNserrFault',
           'NSNitroNserrNotblk',
           'NSNitroNserrBusy',
           'NSNitroNserrExist',
           'NSNitroNserrXdev',
           'NSNitroNserrNodev',
           'NSNitroNserrNotdir',
           'NSNitroNserrIsdir',
           'NSNitroNserrInval',
           'NSNitroNserrNfile',
           'NSNitroNserrMfile',
           'NSNitroNserrNotty',
           'NSNitroNserrTxtbsy',
           'NSNitroNserrFbig',
           'NSNitroNserrNospace',
           'NSNitroNserrSpipe',
           'NSNitroNserrRofs',
           'NSNitroNserrMlink',
           'NSNitroNserrPipe',
           'NSNitroNserrDom',
           'NSNitroNserrRange',
           'NSNitroNserrAgain',
           'NSNitroNserrInprogress',
           'NSNitroNserrAlready',
           'NSNitroNserrNotsock',
           'NSNitroNserrDestaddrreq',
           'NSNitroNserrMsgsize',
           'NSNitroNserrPrototype',
           'NSNitroNserrNoprotoopt',
           'NSNitroNserrProtonosupport',
           'NSNitroNserrSocktnosupport',
           'NSNitroNserrOpnotsupp',
           'NSNitroNserrPfnosupport',
           'NSNitroNserrAfnosupport',
           'NSNitroNserrAddrinuse',
           'NSNitroNserrAddrnotavail',
           'NSNitroNserrNetdown',
           'NSNitroNserrNetunreach',
           'NSNitroNserrNetreset',
           'NSNitroNserrConnaborted',
           'NSNitroNserrConnreset',
           'NSNitroNserrNobufs',
           'NSNitroNserrIsconn',
           'NSNitroNserrNotconn',
           'NSNitroNserrShutdown',
           'NSNitroNserrToomanyrefs',
           'NSNitroNserrTimedout',
           'NSNitroNserrConnrefused',
           'NSNitroNserrLoop',
           'NSNitroNserrNametoolong',
           'NSNitroNserrHostdown',
           'NSNitroNserrHostunreach',
           'NSNitroNserrNotempty',
           'NSNitroNserrProclim',
           'NSNitroNserrUsers',
           'NSNitroNserrDquot',
           'NSNitroNserrStale',
           'NSNitroNserrRemote',
           'NSNitroNserrBadrpc',
           'NSNitroNserrRpcmismatch',
           'NSNitroNserrProgunavail',
           'NSNitroNserrProgmismatch',
           'NSNitroNserrProcunavail',
           'NSNitroNserrNolck',
           'NSNitroNserrNosys',
           'NSNitroNserrFtype',
           'NSNitroNserrAuth',
           'NSNitroNserrNeedauth',
           'NSNitroNserrWouldblock',
           'NSNitroNserrNocode',
           'NSNitroNserrNotsuser',
           'NSNitroNserrBigdata',
           'NSNitroNserrSmalldata',
           'NSNitroNserrNomorent',
           'NSNitroNserrNoservice',
           'NSNitroNserrOserror',
           'NSNitroNserrNonexpcmd',
           'NSNitroNserrCmdpropfail',
           'NSNitroNserrToomanynodes',
           'NSNitroNserrSecondaryfail',
           'NSNitroNserrInvalbackup',
           'NSNitroNserrNoserver',
           'NSNitroNserrLoginreqd',
           'NSNitroNserrRpcinval',
           'NSNitroNserrNouser',
           'NSNitroNserrInvalpasswd',
           'NSNitroNserrLicense',
           'NSNitroNserrDeferred',
           'NSNitroNserrPropauthfail',
           'NSNitroNserrNodelsuser',
           'NSNitroNserrNomodsuser',
           'NSNitroNserrInvalnodeid',
           'NSNitroNserrNotopha',
           'NSNitroNserrNooppeerbad',
           'NSNitroNserrNoopbad',
           'NSNitroNserrNopnow',
           'NSNitroNserrNooppri',
           'NSNitroNserrNoopsec',
           'NSNitroNserrRedirect',
           'NSNitroNserrBufoverflow',
           'NSNitroNserrNouserpolicy',
           'NSNitroNserrNosysgroup',
           'NSNitroNserrNosyscmdpol',
           'NSNitroNserrHaipv6pt',
           'NSNitroNserrHansipv6',
           'NSNitroNserrNsipv6active',
           'NSNitroNserrRtmonStandalone',
           'NSNitroNserrIpv6featDisabled',
           'NSNitroNserrIprangenotallowd',
           'NSNitroNserrIvalidiprange',
           'NSNitroNserrIprangemaxlimit',
           'NSNitroNserrIpNotExist',
           'NSNitroNserrToomanyrules',
           'NSNitroNserrPasswdLenMin8',
           'NSNitroNserrSyncDisabled',
           'NSNitroNserrNodeDisabled',
           'NSNitroNserrSyncProgress',
           'NSNitroNserrAdnsPerm',
           'NSNitroNserrNoincIpsamesubnet',
           'NSNitroNserrInvalidPeerip',
           'NSNitroNserrRedirect307',
           'NSNitroNserrInvalhostname',
           'NSNitroNserrRewriteNotSupported',
           'NSNitroNserrIpchgDeny',
           'NSNitroNserrIpchgGslb',
           'NSNitroNserrGslbIpchg',
           'NSNitroNserrNoauditsrvc',
           'NSNitroNserrLacpkeyNotset',
           'NSNitroNserrChannelInusebylacp',
           'NSNitroNserrLacpenabled',
           'NSNitroNserrIfacemanuallybound',
           'NSNitroNserrIntrecinuse',
           'NSNitroNserrIpportVipConflict',
           'NSNitroNserrIpportVipBound',
           'NSNitroNserrNoBackupVip',
           'NSNitroNserrReqSetArgs',
           'NSNitroNserrSvcgrpMemberNameconflict',
           'NSNitroNserrServerNameExist',
           'NSNitroNserrMaxServiceBindingOnVserver',
           'NSNitroNserrMaxSvcEntityBindingOnSvcgroup',
           'NSNitroNserrFsmall',
           'NSNitroNserrIntoflow',
           'NSNitroNserrAsyncBlocked',
           'NSNitroNserrSaclClearpending',
           'NSNitroNserrSaclNameExists',
           'NSNitroNserrSaclSupersetExists',
           'NSNitroNserrSaclSubsetExists',
           'NSNitroNserrNoincRoutemonitor',
           'NSNitroNserrSessionExpired',
           'NSNitroNserrSessionExceeded',
           'NSNitroNserrCfeConnExceeded',
           'NSNitroNserrCfeConnPerSessExceeded',
           'NSNitroNserrCfeKillself',
           'NSNitroNserrCfeIncompletesession',
           'NSNitroNserrCfeInvalidsession',
           'NSNitroNserrCfeSessionNoexist',
           'NSNitroNserrSysgroupUserExists',
           'NSNitroNserrSysgroupPolicyExists',
           'NSNitroNserrSleep',
           'NSNitroNserrPpedie',
           'NSNitroNserrNoconnCmdpropfail',
           'NSNitroNserrTimeoutSecondary',
           'NSNitroNserrRpcTimeout',
           'NSNitroNserrNotSupported',
           'NSNitroNserrNoentVserver',
           'NSNitroNserrNoentSvc',
           'NSNitroNserrNoentSvcSvcgrp',
           'NSNitroNserrHaNov4Netmask',
           'NSNitroNserrMaxVsevrverBindingsToService',
           'NSNitroNserrSacl6Clearpending',
           'NSNitroNserrSacl6NameExists',
           'NSNitroNserrSacl6SupersetExists',
           'NSNitroNserrSacl6SubsetExists',
           'NSNitroNserrNoBackupVipBound',
           'NSNitroNserrVserverTypeMismatch',
           'NSNitroNserrSessionExpiredRedirect',
           'NSNitroNserrCaconfCnflHeurexpRelexp',
           'NSNitroNserrCaconfCnflHeurexpRelexpmili',
           'NSNitroNserrCaconfCnflRelexpRelexpmili',
           'NSNitroNserrCaconfCnflAbsexpHeurexp',
           'NSNitroNserrCaconfCnflAbsexpRelexpmili',
           'NSNitroNserrCaconfCnflAbsexpgmtHeruexp',
           'NSNitroNserrCaconfCnflAbsexpAbsexpgmt',
           'NSNitroNserrCaconfCnflAbsexpgmtRelexpmili',
           'NSNitroNserrCaconfCnflHitparamsHitslctr',
           'NSNitroNserrCaconfCnflInvalparamsHitslctr',
           'NSNitroNserrCaconfCnflHitparamsInvlslctr',
           'NSNitroNserrCaconfCnflInvalparamsInvlslctr',
           'NSNitroNserrCaconfCnflHitslctrMatchcooky',
           'NSNitroNserrCaconfCnflHitslctrInvalrest2host',
           'NSNitroNserrCaconfCnflHitslctrIgnrparamvalcase',
           'NSNitroNserrCaconfCnflInvalslctrMatchcooky',
           'NSNitroNserrCaconfCnflInvalslctrInvalrest2host',
           'NSNitroNserrCaconfCnflInvalslctrIgnrparamvalcase',
           'NSNitroNserrCaconfCnflPosrelexpRelexp',
           'NSNitroNserrCaconfCnflPosrelexpRelexpmili',
           'NSNitroNserrCaconfCnflAbsexpPosrelexp',
           'NSNitroNserrCaconfCnflAbsexpgmtPosrelexp',
           'NSNitroNserrCaconfCnflIgnrparamvalcaseHitparams',
           'NSNitroNserrCaconfCnflHitInvalparamsMatchcuky',
           'NSNitroNserrCaconfCnflInvalrest2hostInvalparam',
           'NSNitroNserrCaconfCnflPrefetchPrefetchsec',
           'NSNitroNserrCaconfCnflPrefetchPrefetchmili',
           'NSNitroNserrCaconfCnflPrefetchmiliPrefetchsec',
           'NSNitroNserrCaconfArgLeMinVal',
           'NSNitroNserrCaconfArgGeMaxVal',
           'NSNitroNserrPxyCacheHmg',
           'NSNitroNserrPxyRmLastMemt',
           'NSNitroNserrCswInsInvalPfx',
           'NSNitroNserrPengExprIvalName',
           'NSNitroNserrCswBigUrl',
           'NSNitroNserrCswBigPfx',
           'NSNitroNserrCswBigSfx',
           'NSNitroNserrCswInvalSfx',
           'NSNitroNserrExprNomethod',
           'NSNitroNserrExprNourltokens',
           'NSNitroNserrExprNoversion',
           'NSNitroNserrExprNohdr',
           'NSNitroNserrExprNocacntl',
           'NSNitroNserrExprNoprag',
           'NSNitroNserrExprNoquery',
           'NSNitroNserrExprNoqual',
           'NSNitroNserrActionInuse',
           'NSNitroNserrActionHdrInval',
           'NSNitroNserrUrlqInval',
           'NSNitroNserrUndefAction',
           'NSNitroNserrCpeInuse',
           'NSNitroNserrCpeReqactInval',
           'NSNitroNserrCpeRspactInval',
           'NSNitroNserrCpeReqruleInval',
           'NSNitroNserrCpeRspruleInval',
           'NSNitroNserrActionDefinval',
           'NSNitroNserrActionNotpresent',
           'NSNitroNserrPxyInvalServicetype',
           'NSNitroNserrCachepolicyInuse',
           'NSNitroNserrCachegroupInternal',
           'NSNitroNserrCpeInval',
           'NSNitroNserrExprNolen',
           'NSNitroNserrDnswait',
           'NSNitroNserrGwTimeout',
           'NSNitroNserrCswdmnInuse',
           'NSNitroNserrCswdmnPlcyExist',
           'NSNitroNserrActionNomodHdr',
           'NSNitroNserrExprInvalOperator',
           'NSNitroNserrExprDefRemInval',
           'NSNitroNserrExprToomany',
           'NSNitroNserrActionToomany',
           'NSNitroNserrCswpolicyToomany',
           'NSNitroNserrCrdpolicyToomany',
           'NSNitroNserrMappolicyToomany',
           'NSNitroNserrFiltpolicyToomany',
           'NSNitroNserrCachepolicyToomany',
           'NSNitroNserrCachegroupToomany',
           'NSNitroNserrCacheparamMemallocFailed',
           'NSNitroNserrCachegroupInuse',
           'NSNitroNserrCachegroupExpconflict',
           'NSNitroNserrCacheparamInval',
           'NSNitroNserrCachegroupParamInval',
           'NSNitroNserrCachegroupQueryInval',
           'NSNitroNserrActionInval',
           'NSNitroNserrExprDefSetInval',
           'NSNitroNserrCachegroupResszMinGtMax',
           'NSNitroNserrFiltacionInvalrespcode',
           'NSNitroNserrCachegroupHostReq',
           'NSNitroNserrCachegroupHostNreq',
           'NSNitroNserrCachegroupDyngrpNexp',
           'NSNitroNserrCachegroupOneGrpReq',
           'NSNitroNserrCachegroupOneAllReq',
           'NSNitroNserrCachegroupMatchParamInval',
           'NSNitroNserrCachegroupDynResCache',
           'NSNitroNserrExprInvalValue',
           'NSNitroNserrCachegroupPrefetchConflict',
           'NSNitroNserrCachegroupPrefetchEnable',
           'NSNitroNserrCachegroupCchUnknown',
           'NSNitroNserrCachegroupRelexpX10ms',
           'NSNitroNserrCachegroupPrefetchX10ms',
           'NSNitroNserrCachegroupStaticToDynamic',
           'NSNitroNserrPlcyDefRemInval',
           'NSNitroNserrCachegroupPrefetchRelNreq',
           'NSNitroNserrExprSetInvalFlowtype',
           'NSNitroNserrExprTooBig',
           'NSNitroNserrCpeInvalidIdrange',
           'NSNitroNserrExprTooBigExt',
           'NSNitroNserrCachegroupMatchcookieDynReq',
           'NSNitroNserrCachegroupMatchcookieNreq',
           'NSNitroNserrCachefwpxyPresent',
           'NSNitroNserrCachePrefetchReevalNreq',
           'NSNitroNserrCachefwpxyToomany',
           'NSNitroNserrCachePetFcNreq',
           'NSNitroNserrSaveconfigInProgress',
           'NSNitroNserrGwsubnetNotExist',
           'NSNitroNserrGwReqSubnet',
           'NSNitroNserrUrlpolNoPri',
           'NSNitroNserrBadCrAttribs',
           'NSNitroNserrMacNotSupported',
           'NSNitroNserrPolicyNotSupported',
           'NSNitroNserrCacheabilityNotSupported',
           'NSNitroNserrHostRtNotAllowed',
           'NSNitroNserrRoutingNotAllowed',
           'NSNitroNserrConfigNotsaved',
           'NSNitroNserrExprmismatch',
           'NSNitroNserrNoHost',
           'NSNitroNserrNoDflt',
           'NSNitroNserrDfltdmnFirst',
           'NSNitroNserrPxyConfLoop',
           'NSNitroNserrPxyMeDup',
           'NSNitroNserrPxyIvalTgt',
           'NSNitroNserrConnected',
           'NSNitroNserrAuthenticate',
           'NSNitroNserrLargeDomain',
           'NSNitroNserrPxyIvalUrl',
           'NSNitroNserrPxyMeUse',
           'NSNitroNserrPxyMtType',
           'NSNitroNserrPxyMtUse',
           'NSNitroNserrPxyMbInval',
           'NSNitroNserrPxyMbUse',
           'NSNitroNserrPxySetdcdn',
           'NSNitroNserrPxySetdflt',
           'NSNitroNserrPxyDfltNotset',
           'NSNitroNserrPxyFwdIval',
           'NSNitroNserrPxyMtxProt',
           'NSNitroNserrPxyMtxTra',
           'NSNitroNserrPxyMtxFwd',
           'NSNitroNserrPxyMtxRev',
           'NSNitroNserrPxyAddTraNonhttp',
           'NSNitroNserrPxyAddTraOther',
           'NSNitroNserrPxyOptInval',
           'NSNitroNserrPxyAddSvrOther',
           'NSNitroNserrPxyMbDup',
           'NSNitroNserrPxyDfltDup',
           'NSNitroNserrSelInuse',
           'NSNitroNserrSelParseFailed',
           'NSNitroNserrNoselector',
           'NSNitroNserrSelToomany',
           'NSNitroNserrCachegroupNoselparam',
           'NSNitroNserrNocachegroup',
           'NSNitroNserrNonreqSel',
           'NSNitroNserrInvalarg',
           'NSNitroNserrNowildAllowed',
           'NSNitroNserrDateIncompat',
           'NSNitroNserrTimedateInvalid',
           'NSNitroNserrContentgroupCookieReqParam',
           'NSNitroNserrContentgroupIgnorecaseReqHitparam',
           'NSNitroNserrContentgroupInvalparamReq',
           'NSNitroNserrClisecExpTooLong',
           'NSNitroNserrNonhttpCswBindHttpSslPolicy',
           'NSNitroNserrNonhttpCswBindDomainPolicy',
           'NSNitroNserrNonhttpCswBindUrlPolicy',
           'NSNitroNserrPolboundtoTooManyVsvrs',
           'NSNitroNserrPiCswUrlDomain',
           'NSNitroNserrPiToPeCsw',
           'NSNitroNserrPeToPiCsw',
           'NSNitroNserrPriorityCompPiCsw',
           'NSNitroNserrPiTcpcsw',
           'NSNitroNserrPeGoto',
           'NSNitroNserrPiToPePolCsw',
           'NSNitroNserrCacheobjectEvict',
           'NSNitroNserrDnsfail',
           'NSNitroNserrHcRetTypeChange',
           'NSNitroNserrHcNotHttpVs',
           'NSNitroNserrHcReqConfigXor',
           'NSNitroNserrHcServiceConfigXor',
           'NSNitroNserrHcRetTypeReqd',
           'NSNitroNserrRtspCswBindIpPolicy',
           'NSNitroNserrCswBindIncompatTgt',
           'NSNitroNserrAsBadXmlnamespacePrefix',
           'NSNitroNserrInvalidSipExpr',
           'NSNitroNserrNoBackendvserver',
           'NSNitroNserrContentGroupToomany',
           'NSNitroNserrCacheMemSizeChanged',
           'NSNitroNserrCacheMemSizeZero',
           'NSNitroNserrL2connNotAllowed',
           'NSNitroNserrSqlNotAllowed',
           'NSNitroNserrIpsecNotAllowed',
           'NSNitroNserrCswBindIncompatBkup',
           'NSNitroNserrRnatInv',
           'NSNitroNserrInvalidIf',
           'NSNitroNserrMgrlimitReached',
           'NSNitroNserrSpInvaldTable',
           'NSNitroNserrRnatNatipExists',
           'NSNitroNserrRnatExists',
           'NSNitroNserrRnatNotExists',
           'NSNitroNserrRnatNatipNotExists',
           'NSNitroNserrRnatInvalidNatip',
           'NSNitroNserrArpDisabled',
           'NSNitroNserrArpSecNotOwnedip',
           'NSNitroNserrCpeRuleInval',
           'NSNitroNserrInvalFlowtype',
           'NSNitroNserrInvalPolicyType',
           'NSNitroNserrCpeRuleActionInval',
           'NSNitroNserrCpeDefSetInval',
           'NSNitroNserrInvalForcecleanup',
           'NSNitroNserrInvalAaaGroup',
           'NSNitroNserrInvalProxy',
           'NSNitroNserrInvalHtttpproxy',
           'NSNitroNserrInvalFtpproxy',
           'NSNitroNserrInvalSockproxy',
           'NSNitroNserrInvalGopherproxy',
           'NSNitroNserrInvalSslproxy',
           'NSNitroNserrInvalAaagrpMax',
           'NSNitroNserrInvalMaxPortNum',
           'NSNitroNserrInvalHttpport',
           'NSNitroNserrInvalVpnvsererPoltype',
           'NSNitroNserrInvalVpnglobalPoltype',
           'NSNitroNserrCpeRemInuse',
           'NSNitroNserrProxyConflict',
           'NSNitroNserrProxyInval',
           'NSNitroNserrPxyexcptInval',
           'NSNitroNserrCpePoltypeNoCse',
           'NSNitroNserrSessactCseIncompatible',
           'NSNitroNserrNomemCse',
           'NSNitroNserrIncompatFsRule',
           'NSNitroNserrIncompatFsMix',
           'NSNitroNserrDrEnable',
           'NSNitroNserrMaxDistance',
           'NSNitroNserrNullRouteDistance',
           'NSNitroNserrBadActionTcpProfileType',
           'NSNitroNserrBadActionHttpProfileType',
           'NSNitroNserrSpInvalidThreshold',
           'NSNitroNserrVipRouteExists',
           'NSNitroNserrAclNotExists',
           'NSNitroNserrAclExists',
           'NSNitroNserrAclpipWosrcdst',
           'NSNitroNserrAclSameipPip',
           'NSNitroNserrAclInvalPeerip',
           'NSNitroNserrAclIppipExists',
           'NSNitroNserrXacldelerror',
           'NSNitroNserrXacladderror',
           'NSNitroNserrXaclPriorityExists',
           'NSNitroNserrXaclIcmpReqd',
           'NSNitroNserrNoloopback',
           'NSNitroNserrInvicmptype',
           'NSNitroNserrInvicmpcode',
           'NSNitroNserrXaclrnatdel',
           'NSNitroNserrXaclmodcfginfo',
           'NSNitroNserrAcl6IppipExists',
           'NSNitroNserrAcl6Delerror',
           'NSNitroNserrAcl6Adderror',
           'NSNitroNserrAcl6PriorityExists',
           'NSNitroNserrAcl6IcmpReqd',
           'NSNitroNserrAcl6Unspecaddr',
           'NSNitroNserrAcl6Modcfginfo',
           'NSNitroNserrAcl6Prefixlen',
           'NSNitroNserrPbrNexthopNotdirect',
           'NSNitroNserrPbrNoloopback',
           'NSNitroNserrPbrdelerror',
           'NSNitroNserrPbrIppipExists',
           'NSNitroNserrPbrPriorityExists',
           'NSNitroNserrPbrmodcfginfo',
           'NSNitroNserrPbrNexthopReqd',
           'NSNitroNserrPbrL2ConfigInfo',
           'NSNitroNserrPbrmodcfgL2Info',
           'NSNitroNserrPbrNoMonitorGateway',
           'NSNitroNserrPbrInvalidIporgateway',
           'NSNitroNserrPbrMaxRuleExceeded',
           'NSNitroNserrTcpconnfail',
           'NSNitroNserrLoginfail',
           'NSNitroNserrNologin',
           'NSNitroNserrAuthtimeout',
           'NSNitroNserrNotPrimary',
           'NSNitroNserrRemoteop',
           'NSNitroNserrConnlost',
           'NSNitroNserrRpcdatamismatch',
           'NSNitroNserrRpcbadreply',
           'NSNitroNserrUnabletoprompt',
           'NSNitroNserrUserabort',
           'NSNitroNserrEof',
           'NSNitroNserrInterrupt',
           'NSNitroNserrInternal',
           'NSNitroNserrStrmaxlen255',
           'NSNitroNserrStrmaxlen32',
           'NSNitroNserrNoresponse',
           'NSNitroNserrIoerror',
           'NSNitroNserrEnv',
           'NSNitroNserrCmdsfailed',
           'NSNitroNserrAllcmdsfailed',
           'NSNitroNserrInvalidTcpOptionType',
           'NSNitroNserrLicexpired',
           'NSNitroNserrFeatdisabled',
           'NSNitroNserrMaxlimit',
           'NSNitroNserrSetNosupport',
           'NSNitroNserrInvalidvalue',
           'NSNitroNserrInvalidname',
           'NSNitroNserrNosuchcmd',
           'NSNitroNserrCmdambiguous',
           'NSNitroNserrNosucharg',
           'NSNitroNserrArgvalmissing',
           'NSNitroNserrArgsmutex',
           'NSNitroNserrArgprereq',
           'NSNitroNserrArgstoofew',
           'NSNitroNserrArgmissing',
           'NSNitroNserrArgorder',
           'NSNitroNserrArgvalbad',
           'NSNitroNserrArgvalseq',
           'NSNitroNserrArgambiguous',
           'NSNitroNserrSyncgslbconfig',
           'NSNitroNserrSyncgslbconfigWarn',
           'NSNitroNserrArgvalsneq',
           'NSNitroNserrArgvalambiguous',
           'NSNitroNserrStrmaxlen',
           'NSNitroNserrStrminlen',
           'NSNitroNserrIntmaxval',
           'NSNitroNserrIntminval',
           'NSNitroNserrInvalidip',
           'NSNitroNserrInvalidnetmask',
           'NSNitroNserrToomanyvals',
           'NSNitroNserrBadrange',
           'NSNitroNserrExprquotes',
           'NSNitroNserrBadquotes',
           'NSNitroNserrInvalidrange',
           'NSNitroNserrMismatchranges',
           'NSNitroNserrMultiranges',
           'NSNitroNserrNomatchchar',
           'NSNitroNserrNeedreboot',
           'NSNitroNsqSaveconfig',
           'NSNitroNserrNotsaved',
           'NSNitroNserrCmdexec',
           'NSNitroNsqReboot',
           'NSNitroNserrNoreboot',
           'NSNitroNserrPgmfailed',
           'NSNitroNserrCtxmode',
           'NSNitroNserrCmdincomplete',
           'NSNitroNserrCmdoutofctx',
           'NSNitroNserrConfigsaved',
           'NSNitroNserrConfigcleared',
           'NSNitroNserrRebooting',
           'NSNitroNserrNoconfigsave',
           'NSNitroNserrRegexnoanchor',
           'NSNitroNserrRegexnomatch',
           'NSNitroNserrRegexinvalid',
           'NSNitroNserrRegexnotallowed',
           'NSNitroNserrRegexnocmd',
           'NSNitroNserrInvalidipv6Format',
           'NSNitroNserrInvalidipv6TwoDoubecolon',
           'NSNitroNserrInvalidipv6NoprefixLength',
           'NSNitroNserrInvalidipv6PrefixValue',
           'NSNitroNserrTermnameinvalid',
           'NSNitroNserrTerminvalid',
           'NSNitroNserrForcefailover',
           'NSNitroNserrForcefailHealthWarn',
           'NSNitroNserrHellotimeMultiple',
           'NSNitroNserrForcesyncsave',
           'NSNitroNserrErroutfilename',
           'NSNitroNserrRnatipdel',
           'NSNitroNserrInvalidalias',
           'NSNitroNserrNosuchalias',
           'NSNitroNserrAliasexists',
           'NSNitroNserrNosuchfile',
           'NSNitroNserrNotregfile',
           'NSNitroNserrDeprcmd',
           'NSNitroNserrDeprarg',
           'NSNitroNserrNotlogfile',
           'NSNitroNserrNoplenforipv6range',
           'NSNitroNserrInvalidint',
           'NSNitroNserrCmdambiguousUsecompletionsoptions',
           'NSNitroNserrMetadataInvalEntitytype',
           'NSNitroNserrSetnotexist',
           'NSNitroNserrSetargnotexist',
           'NSNitroNserrInvalidDs',
           'NSNitroNserrNosuchcounter',
           'NSNitroNserrInvalidipmask',
           'NSNitroNserrInvalidippat',
           'NSNitroNserrBadrc',
           'NSNitroNserrInvalidrangetype',
           'NSNitroNserrInvalidrangeval',
           'NSNitroNserrInvalidipv6PrefixLength',
           'NSNitroNserrEntitydeleteFail',
           'NSNitroNserrIncompatibleip',
           'NSNitroNserrTranscrIp',
           'NSNitroNserrPasswordMismatch',
           'NSNitroNserrNosuchioctl',
           'NSNitroNserrNotargets',
           'NSNitroNserrCantrecover',
           'NSNitroNserrIgnoredioctl',
           'NSNitroNserrRemoteclose',
           'NSNitroNserrInvalidTarget',
           'NSNitroNserrFileError',
           'NSNitroNserrCommentDropped',
           'NSNitroNserrAggreqTimeout',
           'NSNitroNserrAggread',
           'NSNitroNserrRpcCmdDup',
           'NSNitroNserrRpcCmdNondup',
           'NSNitroNserrCfePeComm',
           'NSNitroNserrAggConfail',
           'NSNitroNserrCfePeTimout',
           'NSNitroNserrAggInvalidresponse',
           'NSNitroNserrNontpsvr',
           'NSNitroNserrAggSendfail',
           'NSNitroNserrCfeAslearnComm',
           'NSNitroNserrNitroInvalidObjectname',
           'NSNitroNserrNitroInvalidJsonInput',
           'NSNitroNserrNitroInvalidJsonDatatype',
           'NSNitroNserrNitroInvalidXmlInput',
           'NSNitroNserrNitroInvalidDatatype',
           'NSNitroNserrNitroInvalidMethod',
           'NSNitroNserrNitroParseError',
           'NSNitroNserrNitroCmdexecFailed',
           'NSNitroNserrNitroInvalidAction',
           'NSNitroNserrNsappTemplateExists',
           'NSNitroNserrNsappInvalidTemplate',
           'NSNitroNserrNsappDirError',
           'NSNitroNserrNsappFileError',
           'NSNitroNserrNsappInvalidAppInput',
           'NSNitroNserrNsappExceededFilelength',
           'NSNitroNserrNsappEndpointInuse',
           'NSNitroNserrNsappProtocolMismatch',
           'NSNitroNserrNsappInvalidVarname',
           'NSNitroNserrNsappZipFile',
           'NSNitroNserrNsappMaxepReached',
           'NSNitroNserrNsappNotExist',
           'NSNitroNserrNsappInvalidServicetype',
           'NSNitroNserrNsappTemplateFormatError',
           'NSNitroNserrNsappAppWithoutAppunits',
           'NSNitroNserrNsappServicrgroupExists',
           'NSNitroNserrSlesslbLbmethodNotsupported',
           'NSNitroNserrSlesslbPersistNotsupported',
           'NSNitroNserrSlesslbTypeNotsupported',
           'NSNitroNserrSlesslbModeNotsupported',
           'NSNitroNserrSlesslbSvcUsipnotset',
           'NSNitroNserrWildcardvipLbmethodInval',
           'NSNitroNserrWildcardvipPersistInval',
           'NSNitroNserrLbSoThreshold',
           'NSNitroNserrConnfailoverUsip',
           'NSNitroNserrConnfailoverService',
           'NSNitroNserrLbSoDynamicconThreshold',
           'NSNitroNserrLbSoAddrvip',
           'NSNitroNserrConnfailoverNotforSless',
           'NSNitroNserrSipNocallid',
           'NSNitroNserrSipNovia',
           'NSNitroNserrSipNocseq',
           'NSNitroNserrSipNoto',
           'NSNitroNserrSipNofrom',
           'NSNitroNserrSipNomaxForwards',
           'NSNitroNserrSipServiceUnavailable',
           'NSNitroNserrSvcNotBound',
           'NSNitroNserrSvctypeMismatch',
           'NSNitroNserrChConNotAllowed',
           'NSNitroNserrChIncompleteHdr',
           'NSNitroNserrSpilloverdisabled',
           'NSNitroNserrMaxtimeexceeded',
           'NSNitroNserrScinvalproto',
           'NSNitroNserrRootrec',
           'NSNitroNserrRootGluerec',
           'NSNitroNserrVipinsertNotSupported',
           'NSNitroNserrVsvrAlrdyBound',
           'NSNitroNserrInvalidWlmBinding',
           'NSNitroNserrVsvrNotBound',
           'NSNitroNserrWlmExists',
           'NSNitroNserrInvalidTimeout',
           'NSNitroNserrConnfailoverIncmode',
           'NSNitroNserrConnfailoverTcpb',
           'NSNitroNserrConnfailoverTcpbSvcBind',
           'NSNitroNserrConnfailoverTcpbSvcParam',
           'NSNitroNserrConnfailoverServiceStatefull',
           'NSNitroNserrConnfailoverSslSvcBind',
           'NSNitroNserrConnfailoverHaIncNode',
           'NSNitroNserrConnfailoverSslSvc',
           'NSNitroNserrInvalidPersistence',
           'NSNitroNserrRtspsessionInvalid',
           'NSNitroNserrLbMethodSameasBackupMethod',
           'NSNitroNserrServerExist',
           'NSNitroNserrLbSoHealth',
           'NSNitroNserrReqRuleMissing',
           'NSNitroNserrConnfailoverBindlo',
           'NSNitroNserrConnfailoverSetwithlo',
           'NSNitroNserrRedirectUrlNotApplicable',
           'NSNitroNserrStatefulConnfailoverIpv6',
           'NSNitroNserrConnfailoverNotSupported',
           'NSNitroNserrNobindOnpush',
           'NSNitroNserrPushVsvr',
           'NSNitroNserrOnlyHttpssl',
           'NSNitroNserrPushBindExists',
           'NSNitroNserrSetPushvsOnly',
           'NSNitroNserrSlessNoSupport',
           'NSNitroNserrConnfailoverV6service',
           'NSNitroNserrConnfailoverVserver',
           'NSNitroNserrNoListenPolicyForDummyvs',
           'NSNitroNserrNormalVsNoneListenpol',
           'NSNitroNserrNoLispriForNoneLispol',
           'NSNitroNserrInvalidPolicyString',
           'NSNitroNserrNodatalenoffforvs',
           'NSNitroNserrLbgrppersiswithrdp',
           'NSNitroNserrPqBindvip',
           'NSNitroNserrPqInvalprio',
           'NSNitroNserrPq2bigrule',
           'NSNitroNserrPqInvalwt',
           'NSNitroNserrPqPolexist',
           'NSNitroNserrPqNopol',
           'NSNitroNserrPq2manyref',
           'NSNitroNserrPqNolbvip',
           'NSNitroNserrPqPhsconfig',
           'NSNitroNserrPqNobind',
           'NSNitroNserrSslCert',
           'NSNitroNserrSslPkey',
           'NSNitroNserrSslNomatch',
           'NSNitroNserrSslCerttype',
           'NSNitroNserrSslNocert',
           'NSNitroNserrSslRefext',
           'NSNitroNserrSslBind',
           'NSNitroNserrSslLink',
           'NSNitroNserrSslNeedSslproto',
           'NSNitroNserrSslNolink',
           'NSNitroNserrSslBindor',
           'NSNitroNserrSslNosvrcert',
           'NSNitroNserrSslIssubmis',
           'NSNitroNserrSslCrl',
           'NSNitroNserrSslNocrl',
           'NSNitroNserrSslDhcount',
           'NSNitroNserrSslSessto',
           'NSNitroNserrSslErsacount',
           'NSNitroNserrSslDhSize',
           'NSNitroNserrDhpath',
           'NSNitroNserrCertheader',
           'NSNitroNserrSessheader',
           'NSNitroNserrCipherPerm',
           'NSNitroNserrSslErsadisabled',
           'NSNitroNserrSslDhdisabled',
           'NSNitroNserrSslSessdisabled',
           'NSNitroNserrSslPkeySize',
           'NSNitroNserrSslNotApplicable',
           'NSNitroNserrSslInternalerr',
           'NSNitroNserrSslNocacert',
           'NSNitroNserrSslRefreshdis',
           'NSNitroNserrSslSvrportneeded',
           'NSNitroNserrSslBaseobjneeded',
           'NSNitroNserrSslCipherRedirect',
           'NSNitroNserrSslNodsa',
           'NSNitroNserrSslFipsrefext',
           'NSNitroNserrSslNofipskey',
           'NSNitroNserrNofipscard',
           'NSNitroNserrFipscardnotconf',
           'NSNitroNserrSslSslv2Redirect',
           'NSNitroNserrSslModsize64',
           'NSNitroNserrSslNonfipskey',
           'NSNitroNserrNfipsFipsUpd',
           'NSNitroNserrFipsNfipsUpd',
           'NSNitroNserrSslIssuerNotinGlbcertlist',
           'NSNitroNserrSslCrlsigcheckFail',
           'NSNitroNserrSslPortrewrite',
           'NSNitroNserrSslSslv2RenegClientCert',
           'NSNitroNserrSslBrklink',
           'NSNitroNserrSslCertNotYetValid',
           'NSNitroNserrSslCertExpired',
           'NSNitroNserrSslExpiredBrklink',
           'NSNitroNserrSslNyvalidBrklink',
           'NSNitroNserrSslOcspRespcert',
           'NSNitroNserrSslOcspSigncert',
           'NSNitroNserrSslOcspAia',
           'NSNitroNserrSslFipscardlocked',
           'NSNitroNserrSslDomincompat',
           'NSNitroNserrSslNomthdchange',
           'NSNitroNserrSslUrlsrvrneeded',
           'NSNitroNserrSslInvalidUrl',
           'NSNitroNserrSslMixparams',
           'NSNitroNserrSslPkeyMinsize',
           'NSNitroNserrSslSyncinprogress',
           'NSNitroNserrSslSyncfailed',
           'NSNitroNserrSslCiphgrpRefcnt',
           'NSNitroNserrSslCvmNodsa',
           'NSNitroNserrCerthashheader',
           'NSNitroNserrSslCrlinrefresh',
           'NSNitroNserrSslCrlmemExceeds',
           'NSNitroNserrSslCrlindeletion',
           'NSNitroNserrSslIndeleteNorefresh',
           'NSNitroNserrSslInrefreshNodelete',
           'NSNitroNserrNomix',
           'NSNitroNserrNopolicyNontrsvc',
           'NSNitroNserrSslSslpolBindConst',
           'NSNitroNserrSslNoUsableCiphers',
           'NSNitroNserrSslCertNotCa',
           'NSNitroNserrSslCacertNoCrlsign',
           'NSNitroNserrSslCrlExpired',
           'NSNitroNserrSslCrlNotyetValid',
           'NSNitroNserrSslParsingDeltaCrlExtn',
           'NSNitroNserrSslDeltaCrlMissingBaseCrl',
           'NSNitroNserrNofipscipher',
           'NSNitroNserrNofipsciphergrp',
           'NSNitroNserrNonfipsciphertogrp',
           'NSNitroNserrNonfipsaliastogrp',
           'NSNitroNserrNonfipsgrouptogrp',
           'NSNitroNserrSslImportFipskeyNameMismatch',
           'NSNitroNserrSslPkeySizeCa',
           'NSNitroNserrSslCrlPortMismatch',
           'NSNitroNserrSslPkeySizeVpx',
           'NSNitroNserrSslDhSizeVpx',
           'NSNitroNserrNoentCipher',
           'NSNitroNserrFipsfwwrongmajor',
           'NSNitroNserrFipsfwwrongminor',
           'NSNitroNserrFipsfwupdated',
           'NSNitroNserrSslPendingCmds',
           'NSNitroNserrFipsfwupdatedoreboot',
           'NSNitroNserrSslSniNotenable',
           'NSNitroNserrSslNoCn',
           'NSNitroNserrSslDupSnicert',
           'NSNitroNserrSslSniNotvalidServ',
           'NSNitroNserrOcspReferences',
           'NSNitroNserrOcspSignerNokey',
           'NSNitroNserrSslNotSupported',
           'NSNitroNserrOcspTooManyResponders',
           'NSNitroNserrOcspNoDnsServerConfigured',
           'NSNitroNserrSslDupSnicertBrklink',
           'NSNitroNserrSslNoCnBrllink',
           'NSNitroNserrNgfipsresetreboot',
           'NSNitroNserrNgfipsinitreboot',
           'NSNitroNserrFipscmdtimeout',
           'NSNitroNserrSslSimtimeout',
           'NSNitroNserrSslNgfipsQfull',
           'NSNitroNserrSslNomemVsvrsrvlistnode',
           'NSNitroNserrSslCertkeySize64',
           'NSNitroNserrSniAtk',
           'NSNitroNserrSniNohosthdr',
           'NSNitroNserrCrlShmemAllocFail',
           'NSNitroNserrSslCertMissingParam',
           'NSNitroNserrSslNomemCertkeyOcsprespListnode',
           'NSNitroNserrSslBundleIcFileExists',
           'NSNitroNserrSslBundleScertMissing',
           'NSNitroNserrSslBundleCertMissing',
           'NSNitroNserrSslBundleFailed',
           'NSNitroNserrSslBundleParseErr',
           'NSNitroNserrSslBundleMaxCert',
           'NSNitroNserrSslBundleMaxKey',
           'NSNitroNserrSslBundleIcFileCreateFailed',
           'NSNitroNserrSslIssuerMismatch',
           'NSNitroNserrSslConffile',
           'NSNitroNserrSslNoconffile',
           'NSNitroNserrSslSigfail',
           'NSNitroNserrSslInvalformat',
           'NSNitroNserrSslOutfile',
           'NSNitroNserrSslVerifyFail',
           'NSNitroNserrSslFilecreate',
           'NSNitroNserrSslMinkeysize',
           'NSNitroNserrSslInvalidReq',
           'NSNitroNserrSslGentool',
           'NSNitroNserrSslPemOnly',
           'NSNitroNserrSslPassmismatch',
           'NSNitroNserrSslPassreq',
           'NSNitroNserrSslInvalpass',
           'NSNitroNserrSslMaxkeysize',
           'NSNitroNserrSslGntoolargMissing',
           'NSNitroNserrSslInvalPubexp',
           'NSNitroNserrSslInvalidValue',
           'NSNitroNserrSslMissingKval',
           'NSNitroNserrSslInvalDhgen',
           'NSNitroNserrSslNofileCertreq',
           'NSNitroNserrSslReqNomatch',
           'NSNitroNserrSslPkcs12',
           'NSNitroNserrSslNofileCapvtkey',
           'NSNitroNserrSslNofileCacert',
           'NSNitroNserrSslNofileSerial',
           'NSNitroNserrSslNofilePkcs12',
           'NSNitroNserrSslReadCacert',
           'NSNitroNserrReadCert',
           'NSNitroNserrImpExpNotTogether',
           'NSNitroNserrNofileCert',
           'NSNitroNserrNofileKey',
           'NSNitroNserrCacertpkeyMismatch',
           'NSNitroNserrWrongRevEntry',
           'NSNitroNserrWrongRevDate',
           'NSNitroNserrWrongSerialNo',
           'NSNitroNserrCreateDatabaseEntry',
           'NSNitroNserrAlreadyRevkd',
           'NSNitroNserrLoadPkey',
           'NSNitroNserrCertpkeyNeeded',
           'NSNitroNserrPkcs12Needed',
           'NSNitroNserrErrFileexists',
           'NSNitroNserrFipskeyKeyfileOption',
           'NSNitroNserrOutfilelenbig',
           'NSNitroNserrSslDefpath',
           'NSNitroNserrSslCrlDefpath',
           'NSNitroNserrSslDeflocation',
           'NSNitroNserrDhreqd',
           'NSNitroNserrSslCrlDeflocation',
           'NSNitroNserrSslNofipsKey',
           'NSNitroNserrSslImproperSerialfile',
           'NSNitroNserrSslSerialNumRevoked',
           'NSNitroNserrSslMaxrsakeysize',
           'NSNitroNserrSslMustbepem',
           'NSNitroNserrSslCantbepem',
           'NSNitroNserrSslBadLabel',
           'NSNitroNserrBadDnsOption',
           'NSNitroNserrDnsBadCachetype',
           'NSNitroNserrDnsNotavail',
           'NSNitroNserrDnsBadVstype',
           'NSNitroNserrGslbSitelkupFailed',
           'NSNitroNserrNoarec',
           'NSNitroNserrInvalttl',
           'NSNitroNserrCnameexists',
           'NSNitroNserrInvalSvcoption',
           'NSNitroNserrGslbbindExists',
           'NSNitroNserrNotLocalremote',
           'NSNitroNserrCountMismatch',
           'NSNitroNserrIpMismatch',
           'NSNitroNserrSvcipRepeat',
           'NSNitroNserrNotRemote',
           'NSNitroNserrNotLocal',
           'NSNitroNserrProxyRec',
           'NSNitroNserrNoproxyArec',
           'NSNitroNserrSvcGslbbindExists',
           'NSNitroNserrSvctypemismatch',
           'NSNitroNserrInvalidPubipOption',
           'NSNitroNserrInvalNameSyntax',
           'NSNitroNserrGslbBackup',
           'NSNitroNserrIsBackup',
           'NSNitroNserrGslbHasBackup',
           'NSNitroNserrGslbRequiresIndependentBackup',
           'NSNitroNserrGslbNoqualifier',
           'NSNitroNserrGslbNoname',
           'NSNitroNserrGslbCustomNospace',
           'NSNitroNserrGslbStaticNospace',
           'NSNitroNserrGslbsitenameExists',
           'NSNitroNserrGslbsiteipExists',
           'NSNitroNserrNoGslbsite',
           'NSNitroNserrLocalExists',
           'NSNitroNserrNoGslbsvc',
           'NSNitroNserrNoGslbvip',
           'NSNitroNserrNoDmn',
           'NSNitroNserrDmnNotbound',
           'NSNitroNserrGslbdomainBound',
           'NSNitroNserrNotGslbent',
           'NSNitroNserrGslbdomainPerm',
           'NSNitroNserrGslbMaxqual',
           'NSNitroNserrGslbMaxloclength',
           'NSNitroNserrGslbvipPerm',
           'NSNitroNserrGslbsvcPerm',
           'NSNitroNserrGslbMaxsites',
           'NSNitroNserrGslbQualtoolong',
           'NSNitroNserrGslbPersistidexists',
           'NSNitroNserrGslbInvldLdnstoIntvl',
           'NSNitroNserrVipBackupIsgslb',
           'NSNitroNserrGslbPubipPubportExists',
           'NSNitroNserrGslblocalsvcEnadisNotallowed',
           'NSNitroNserrGslblocalsvrEnadisNotallowed',
           'NSNitroNserrInvalidPersistid',
           'NSNitroNserrPermPersistid',
           'NSNitroNserrInvalidLocalsiteip',
           'NSNitroNserrInvalidRemotesiteip',
           'NSNitroNserrInvalidSitetype',
           'NSNitroNserrInvalidBackupip',
           'NSNitroNserrGslbvipMaxsvc',
           'NSNitroNserrInvalidJitter',
           'NSNitroNserrGslblocsvcDisNotallowd',
           'NSNitroNserrDummybkupNotallowd',
           'NSNitroNserrGslbsvcBindNotallowd',
           'NSNitroNserrNsmapVersion',
           'NSNitroNserrNsmapFormat',
           'NSNitroNserrNsmapEof',
           'NSNitroNserrNsmapParse',
           'NSNitroNserrNsmapRead',
           'NSNitroNserrNsmapWrite',
           'NSNitroNserrNsmapIoctl',
           'NSNitroNserrNsmapOutputfile',
           'NSNitroNserrNsmapInputfile',
           'NSNitroNserrNsmapRequiredField',
           'NSNitroNserrNsmapDbfile',
           'NSNitroNserrNsmapDbinsert',
           'NSNitroNserrNsmapDbsearch',
           'NSNitroNserrGslbproxmLicenceAbsent',
           'NSNitroNserrGslbSitepersistenceHttponly',
           'NSNitroNserrGslbNositepfx',
           'NSNitroNserrGslbSiteprefixSize',
           'NSNitroNserrGslbSitedomainSize',
           'NSNitroNserrGslbSitedomainSyntax',
           'NSNitroNserrGslbSitedomainRefers',
           'NSNitroNserrGslbdomainRefers',
           'NSNitroNserrGslbArecordExists',
           'NSNitroNserrGslbSitecookieTimeoutRange',
           'NSNitroNserrGslbdomainSyntax',
           'NSNitroNserrGslbSoPerm',
           'NSNitroNserrGslbDeprcookietout',
           'NSNitroNserrDnsNamesvrSyntax',
           'NSNitroNserrDnsOrigsvrSyntax',
           'NSNitroNserrDnsContactSyntax',
           'NSNitroNserrDnsMxSyntax',
           'NSNitroNserrDnsCnameSyntax',
           'NSNitroNserrDnsAliasSyntax',
           'NSNitroNserrGslbNolocalvip',
           'NSNitroNserrGslbLocalsvcexists',
           'NSNitroNserrGslblocalsvcPerm',
           'NSNitroNserrDnsInvalRevdomnameSyntax',
           'NSNitroNserrDnsAliasrec',
           'NSNitroNserrGslblocsvcDelayedcleanNotallowd',
           'NSNitroNserrNoBkpVip',
           'NSNitroNserrGslbNosuchLdnsentry',
           'NSNitroNserrMaxDnsView',
           'NSNitroNserrGslbSiteIpExists',
           'NSNitroNserrGslbLastMip',
           'NSNitroNserrRmGslbSite',
           'NSNitroNserrGslbIprmLastMip',
           'NSNitroNserrGslbSvcPubPortErr',
           'NSNitroNserrRecHasRef',
           'NSNitroNserrDnsViewRef',
           'NSNitroNserrGslbSitePersistenceMatch',
           'NSNitroNserrGslbSitePersistenceConflicts',
           'NSNitroNserrDnsPolicyInval',
           'NSNitroNserrGslbvipCnameMismatch',
           'NSNitroNserrGslbvipCnameUnsupportedLbmethods',
           'NSNitroNserrGslbServiceMonNoipport',
           'NSNitroNserrGslbServiceMonSetNoipport',
           'NSNitroNserrGslbCnameServiceSet',
           'NSNitroNserrGslbCnameVserverSet',
           'NSNitroNserrGslbvipCnameUnsupportedBkupLbmethods',
           'NSNitroNserrGslbvipCnameUnsupportedEdr',
           'NSNitroNserrGslbvipCnameUnsupportedMir',
           'NSNitroNserrGslbsvcViewNexist',
           'NSNitroNserrDnsTtlMoreThanMaxAllowed',
           'NSNitroNserrGslbLbMaxsites',
           'NSNitroNserrGslbHaschildren',
           'NSNitroNserrGslbParentischild',
           'NSNitroNserrMaxRltSelectors',
           'NSNitroNserrMaxRltIdentifers',
           'NSNitroNserrNoSuchSelector',
           'NSNitroNserrNoSuchIdentifier',
           'NSNitroNserrRltTimesliceInvalidVal',
           'NSNitroNserrIllegalSubnetMask',
           'NSNitroNserrRltSelectorInuse',
           'NSNitroNserrRltIdentifierInuse',
           'NSNitroNserrRltSelectorCannotChangeAttribType',
           'NSNitroNserrGslbIgnTrigmon',
           'NSNitroNserrRltSelectorNotMoreThan2Ipv6Exp',
           'NSNitroNserrRepeatedMonitors',
           'NSNitroNserrAllMonitorsDisabled',
           'NSNitroNserrGslbAaaarecordExists',
           'NSNitroNserrGslbvipHeterogeneousServiceIpversion',
           'NSNitroNserrViewipIpv6',
           'NSNitroNserrBackupipIpv6',
           'NSNitroNserrBackupVipMismatch',
           'NSNitroNserrGslbDomainConversion',
           'NSNitroNserrGslbIpv4Backupip',
           'NSNitroNserrRltCannotAddSelector',
           'NSNitroNserrRltSelConflictingAttributes',
           'NSNitroNserrGslbvipCnameBackupip',
           'NSNitroNserrGslbHeterogeneousSiteip',
           'NSNitroNserrGslbUnused1',
           'NSNitroNserrGslbUnused2',
           'NSNitroNserrAaaaRecordExists',
           'NSNitroNserrGslbRectypeService',
           'NSNitroNserrGslbRectypeDomain',
           'NSNitroNserrGslbRectypeBackupVip',
           'NSNitroNserrGslbBkpvipRectype',
           'NSNitroNserrGslbUnused3',
           'NSNitroNserrBackupipIpv4',
           'NSNitroNserrGslbIpv6Backupip',
           'NSNitroNserrGslbDbReqTooBig',
           'NSNitroNserrGslbDbQueueMaxed',
           'NSNitroNserrGslbDbServer',
           'NSNitroNserrGslbDbTimeout',
           'NSNitroNserrGslbDbClosed',
           'NSNitroNserrGslbCoordinates',
           'NSNitroNserrInvalidIpv6Prefixlen',
           'NSNitroNserrGslbdomainCanmeRecordExists',
           'NSNitroNserrGslbdomainAaaaCnameExists',
           'NSNitroNserrGslbNonParentRemotesite',
           'NSNitroNserrZoneExists',
           'NSNitroNserrInvalKeyflags',
           'NSNitroNserrDnskeyNonexists',
           'NSNitroNserrNorecsInZone',
           'NSNitroNserrSignfailed',
           'NSNitroNserrDigestinitFailed',
           'NSNitroNserrDigestupdateFailed',
           'NSNitroNserrKeyexists',
           'NSNitroNserrNopasvkeys',
           'NSNitroNserrDnsMaxkeysize',
           'NSNitroNserrNodataToSign',
           'NSNitroNserrCnameSiteNotexists',
           'NSNitroNserrDnsNosoaNons',
           'NSNitroNserrDnsProxyZone',
           'NSNitroNserrNoactvkeys',
           'NSNitroNserrNotifyperiod',
           'NSNitroNserrLoadPubkey',
           'NSNitroNserrDnskeygenUnsupportedAlgo',
           'NSNitroNserrDnskeygenErrPubfileOpen',
           'NSNitroNserrDnskeygenErrPrivfileOpen',
           'NSNitroNserrDnskeygenErrDsfileOpen',
           'NSNitroNserrGslbOptNotsupported',
           'NSNitroNserrGslbGfsNotSupported',
           'NSNitroNserrNsmapImportfile',
           'NSNitroNserrDnsCnameloop',
           'NSNitroNscfgInfo',
           'NSNitroNscsInfo',
           'NSNitroNscsprobeInfo',
           'NSNitroNsappprobeInfo',
           'NSNitroNscfgMpInfo',
           'NSNitroNserrNointranetip',
           'NSNitroNserrAlreadylogedin',
           'NSNitroNserrUrlinuse',
           'NSNitroNserrVpnappinuse',
           'NSNitroNserrNotsuppTransIntercpt',
           'NSNitroNserrNotsuppProtUdp',
           'NSNitroNserrDefaultcmdplcy',
           'NSNitroNserrClntCertReqd',
           'NSNitroNserrInvalCertfield',
           'NSNitroNserrVpnappProxyIprange',
           'NSNitroNserrVpnappProxyNetmask',
           'NSNitroNserrVpnappProxyDstportRange',
           'NSNitroNserrVpnappProxyProtocol',
           'NSNitroNserrVpnappProxyHostname',
           'NSNitroNserrVpnappTransSrcip',
           'NSNitroNserrVpnappTransSrcport',
           'NSNitroNserrVpnappNoInterceptionType',
           'NSNitroNserrVpnappCliappPort',
           'NSNitroNserrVpnappCliappProto',
           'NSNitroNserrVpnappProxyCliapp',
           'NSNitroNserrVpnappMissingProto',
           'NSNitroNserrVpnappMissingArg',
           'NSNitroNserrVpnappTooManyArg',
           'NSNitroNserrFsAuthfail',
           'NSNitroNserrNsipv6notpresent',
           'NSNitroNserrRemoveSession',
           'NSNitroNserrStawiExist',
           'NSNitroNserrInvalidSsoAction',
           'NSNitroNserrInvalidTmtrafficAction',
           'NSNitroNserrInvalfsso',
           'NSNitroNserrInvalidurl',
           'NSNitroNserrInvalidpol',
           'NSNitroNserrNopol',
           'NSNitroNserrRuleurl',
           'NSNitroNserrDelmc',
           'NSNitroNserrAcp',
           'NSNitroNserrAcs',
           'NSNitroNserrNosetCexp',
           'NSNitroNserrCexpDepth',
           'NSNitroNserrNovpnapp',
           'NSNitroNserrNosetCse',
           'NSNitroNserrInvalPolname',
           'NSNitroNserrUnbindInvalidpol',
           'NSNitroNserrExceedMaxPolLimit',
           'NSNitroNserrInternalPiError',
           'NSNitroNserrInterfacebound',
           'NSNitroNserrIfaceNoUnbind',
           'NSNitroNserrIfaceMaxVlans',
           'NSNitroNserrMonitorInterval',
           'NSNitroNserrMonitorDestip',
           'NSNitroNserrMonitorCodes',
           'NSNitroNserrMonitorRef',
           'NSNitroNserrMonitorBuiltin',
           'NSNitroNserrMonitorBound',
           'NSNitroNserrMonitorType',
           'NSNitroNserrMonitorLocal',
           'NSNitroNserrTimeoutRange',
           'NSNitroNserrInvalidhashlen',
           'NSNitroNserrNotauthorized',
           'NSNitroNserrMonitorDefault',
           'NSNitroNserrMonitorLdnsAddPerm',
           'NSNitroNserrMonitorLdnsBindPerm',
           'NSNitroNserrBackupLoop',
           'NSNitroNserrSecureUdp',
           'NSNitroNserrMonitorWrongType',
           'NSNitroNserrLrtmPerm',
           'NSNitroNserrMonitorScriptname',
           'NSNitroNserrMonitorDispatcherip',
           'NSNitroNserrMonitorUserperm',
           'NSNitroNserrMonitorNocodes',
           'NSNitroNserrInvalMon',
           'NSNitroNserrTypeExists',
           'NSNitroNserrMonitorUnbindDefault',
           'NSNitroNserrMonitorBindDefault',
           'NSNitroNserrMonitorDisableDefault',
           'NSNitroNserrDrtmPerm',
           'NSNitroNserrMonDtrmDeviation',
           'NSNitroNserrMonitorInvalidValue',
           'NSNitroNserrMonitorNotBound',
           'NSNitroNserrInvalidMonitor',
           'NSNitroNserrMonitorNoSuchipaddr',
           'NSNitroNserrMonitorScriptArgSize',
           'NSNitroNserrMetrictableNoent',
           'NSNitroNserrMetrictableExist',
           'NSNitroNserrDelMetrictablePermanent',
           'NSNitroNserrMaxMetricBinding',
           'NSNitroNserrMetricNoent',
           'NSNitroNserrMetricExists',
           'NSNitroNserrOidExist',
           'NSNitroNserrSnmpOidInval',
           'NSNitroNserrMetrictableRdonly',
           'NSNitroNserrThresholdZero',
           'NSNitroNserrLdapMonitorIncomplete',
           'NSNitroNserrMysqlMonitorIncomplete',
           'NSNitroNserrPop3MonitorIncomplete',
           'NSNitroNserrNntpMonitorIncomplete',
           'NSNitroNserrFtpextendedMonitorIncomplete',
           'NSNitroNserrSnmpMonitorIncomplete',
           'NSNitroNserrCitrixXmlService',
           'NSNitroNserrCitrixWebInterface',
           'NSNitroNserrLdnsMonCantDisable',
           'NSNitroNserrResRetryOnIpSvr',
           'NSNitroNserrIpOnDbsSvr',
           'NSNitroNserrMonitorAlertretries',
           'NSNitroNserrMonitorFailureretries',
           'NSNitroNserrMonitorAlertfailureretries',
           'NSNitroNserrMonitorIp',
           'NSNitroNserrMonitorSubnet',
           'NSNitroNserrMonitorStatic',
           'NSNitroNserrTosidNotSet',
           'NSNitroNserrFailureretriesNotSupported',
           'NSNitroNserrSuccessretriesNotSupported',
           'NSNitroNserrSetvsInvalMysqlparams',
           'NSNitroNserrSetvsInvalProtocolParams',
           'NSNitroNserrSetvsInvalProtocolsParams',
           'NSNitroNserrDdcValidateCredRequired',
           'NSNitroNserrCitrixWiExtendedMonitorIncomplete',
           'NSNitroNserrSvcporttype',
           'NSNitroNserrVipInGroup',
           'NSNitroNserrUnsupportedBkp',
           'NSNitroNserrNonhttpsslVipingrp',
           'NSNitroNserrNonhttpVipingrp',
           'NSNitroNserrUseProperRmCmd',
           'NSNitroNserrLbmethodNotSupported',
           'NSNitroNserrPersistenceNotSupported',
           'NSNitroNserrVserverParameters',
           'NSNitroNserrServiceParameters',
           'NSNitroNserrLbvipDelete',
           'NSNitroNserrCachepolicyRespactionInval',
           'NSNitroNserrCachelicenseFailed',
           'NSNitroNserrLbvipMultiroutes',
           'NSNitroNserrLbmacInval',
           'NSNitroNserrCachestatsObjNotpresent',
           'NSNitroNserrCachepolicyNotactive',
           'NSNitroNserrCacheBuiltinsNotSourced',
           'NSNitroNserrCachepolicyPriorityInval',
           'NSNitroNserrRoute6DefaultOnly',
           'NSNitroNserrRoute6DefaultExists',
           'NSNitroNserrRoute6InvalidGateway',
           'NSNitroNserrRoute6Max',
           'NSNitroNserrRoute6NotExist',
           'NSNitroNserrIpv6InvalidAddr',
           'NSNitroNserrLbvipIpv6tov4',
           'NSNitroNserrIpv6Nsiptovip',
           'NSNitroNserrIpv6Viptonsip',
           'NSNitroNserrIpv6Scope',
           'NSNitroNserrLbvipIpv4tov6',
           'NSNitroNserrIpv6Linklocaltovip',
           'NSNitroNserrIpv6Mapiponnsip',
           'NSNitroNserrSecureipportaddrinuse',
           'NSNitroNserrIpv6InvalidPrefix',
           'NSNitroNserrNd6LinklocalVlan',
           'NSNitroNserrNd6VlanIntf',
           'NSNitroNserrPersistTimeoutToDefault',
           'NSNitroNserrLbGroupNotExist',
           'NSNitroNserrLbVserverAlreadyBound',
           'NSNitroNserrNameSvrExists',
           'NSNitroNserrNameSvrIdnsNempty',
           'NSNitroNserrNameSvrIvalpolicy',
           'NSNitroNserrNameSvrIvalproto',
           'NSNitroNserrNameSvrAddNexistVip',
           'NSNitroNserrNameSvrNexist',
           'NSNitroNserrNameSvrIdnsPerm',
           'NSNitroNserrNameSvrIpExists',
           'NSNitroNserrErrAaaLicense',
           'NSNitroNserrUsrNointraip',
           'NSNitroNserrUsrNotconfigured',
           'NSNitroNserrInvalAaaGrp',
           'NSNitroNserrInvalCombnation',
           'NSNitroNserrInvalMipIip',
           'NSNitroNserrInvalMipoffIipoff',
           'NSNitroNserrUserexist',
           'NSNitroNserrGroupexist',
           'NSNitroNserrUseralreadybound',
           'NSNitroNserrUsernotbound',
           'NSNitroNserrEntitynotbound',
           'NSNitroNserrGroupnotexist',
           'NSNitroNserrInvalidloglevel',
           'NSNitroNserrDhMisconfig',
           'NSNitroNserrDhIpport',
           'NSNitroNserrDhinuse',
           'NSNitroNserrInvalAaaglobalPoltype',
           'NSNitroNserrNoIp',
           'NSNitroNserrAaatmLic',
           'NSNitroNserrAaatmDisabled',
           'NSNitroNserrNoAuthHost',
           'NSNitroNserrAuthOn',
           'NSNitroNserrKillpending',
           'NSNitroNserrAaatmNoAuthVs',
           'NSNitroNserrAaatm401authOn',
           'NSNitroNserrUnauthrzed',
           'NSNitroNserrKillInprogress',
           'NSNitroNserrWiFrmNotexist',
           'NSNitroNserrWiFrmLast',
           'NSNitroNserrWiNotinst',
           'NSNitroNserrWiGenfailed',
           'NSNitroNserrWiSiteExist',
           'NSNitroNserrWiSiteNotexist',
           'NSNitroNserrWiSiteInvalAgurl',
           'NSNitroNserrWiSiteInvalStaurl',
           'NSNitroNserrWiSiteOnlyMpx',
           'NSNitroNserrWiInstfailed',
           'NSNitroNserrWiMaxsiteExcd',
           'NSNitroNserrWiStawithoutagurl',
           'NSNitroNserrWiAgurlwithoutsta',
           'NSNitroNserrWiRelwithoutagurl',
           'NSNitroNserrWiAuthwithoutagurl',
           'NSNitroNserrWiTwotktwithoutrel',
           'NSNitroNserrWiTwotktwithoutsecsta',
           'NSNitroNserrWiSecstasame',
           'NSNitroNserrWiLicense',
           'NSNitroNserrWiSecstawithoutsta',
           'NSNitroNserrAuthNegotiate',
           'NSNitroNserrWiInstsitesreduced',
           'NSNitroNserrWiIncompatibleauthpoint',
           'NSNitroNserrWiSiteWithinSite',
           'NSNitroNserrTmInvalidPersConfig',
           'NSNitroNserrRwActInval',
           'NSNitroNserrRwUndefactInval',
           'NSNitroNserrActflowmismatch',
           'NSNitroNserrRonlyTarExpr',
           'NSNitroNserrPatsetBindfail',
           'NSNitroNserrPatsetUnbindfail',
           'NSNitroNserrPatsetNotpresent',
           'NSNitroNserrRspActInval',
           'NSNitroNserrRspPolicyFlowtypeReq',
           'NSNitroNserrTarFlowtypeNres',
           'NSNitroNserrRspConfigLock',
           'NSNitroNserrRspActMustBeNoop',
           'NSNitroNserrPatsetInvalidRegex',
           'NSNitroNserrPatsetBindfailDupIndex',
           'NSNitroNserrPatsetBindfailIndexNotGiven',
           'NSNitroNserrPatsetBindfailIndexNotRequired',
           'NSNitroNserrPatsetBindfailPatlenLtWuMinlen',
           'NSNitroNserrTargetNotAllowedInRule',
           'NSNitroNserrRwTargetNotAllowedInStrbuilder',
           'NSNitroNserrPitInval',
           'NSNitroNserrInvalInvokepoint',
           'NSNitroNserrPitMaxPacket',
           'NSNitroNserrRefineSearchInvalid',
           'NSNitroNserrExtendInvalid',
           'NSNitroNserrNonExtendExpr',
           'NSNitroNserrExtendInvalPirl',
           'NSNitroNserrInvalTarExpr',
           'NSNitroNserrInvalPatternSearchSet',
           'NSNitroNserrInvalSearchArgs',
           'NSNitroNserrRspActMustBeResetDrop',
           'NSNitroNserrInvalSearchSyntax',
           'NSNitroNserrInvalSearchXpathSyntax',
           'NSNitroNserrInvalSearchPatsetSyntax',
           'NSNitroNserrInvalSearchRegexSyntax',
           'NSNitroNserrRwReqBodyNotAllowed',
           'NSNitroNserrRenameNotsupported',
           'NSNitroNserrEntityRemovalNotallowed',
           'NSNitroNserrPiEntityExists',
           'NSNitroNserrIncompatibleCalloutChange',
           'NSNitroNserrStringmapNotpresent',
           'NSNitroNserrUrltransMaxEntities',
           'NSNitroNserrUrltransInvalProfile',
           'NSNitroNserrUrltransActionInuse',
           'NSNitroNserrUrltransPriorityExists',
           'NSNitroNserrUrltransReqPcreErr',
           'NSNitroNserrUrltransRespPcreErr',
           'NSNitroNserrUrltransReqIntoErr',
           'NSNitroNserrUrltransRespIntoErr',
           'NSNitroNserrUrltransCookieIntoErr',
           'NSNitroNserrUrltransCookiePcreErr',
           'NSNitroNserrUrltransTooManyBackrefs',
           'NSNitroNserrUrltransMissingFrom',
           'NSNitroNserrPiLongvsvrname',
           'NSNitroNserrPiPriorityExists',
           'NSNitroNserrInvalpiexpr',
           'NSNitroNserrInvalintop',
           'NSNitroNserrInvalcompare',
           'NSNitroNserrInvalboolop',
           'NSNitroNserrArgneg',
           'NSNitroNserrArgexceed',
           'NSNitroNserrArgzero',
           'NSNitroNserrMaxheader',
           'NSNitroNserrInvalpicexpr',
           'NSNitroNserrCexprlimit',
           'NSNitroNserrExprlimit',
           'NSNitroNserrSexprlimit',
           'NSNitroNserrInvalpisexpr',
           'NSNitroNserrNobidi',
           'NSNitroNserrNolab',
           'NSNitroNserrInternalLabelRm',
           'NSNitroNserrPolicyFlowtypeNone',
           'NSNitroNserrInvalPriority',
           'NSNitroNserrNumericexpr',
           'NSNitroNserrBoolexpr',
           'NSNitroNserrNotbound',
           'NSNitroNserrPolicyInuse',
           'NSNitroNserrPolicySetNotallowed',
           'NSNitroNserrInvalidBind',
           'NSNitroNserrUseInvokeResult',
           'NSNitroNserrInvalUnbind',
           'NSNitroNserrRegexInvalid',
           'NSNitroNserrRegexBackref',
           'NSNitroNserrRegexRecursive',
           'NSNitroNserrPixlExprUnsafe',
           'NSNitroNserrPiActionMaxRefReached',
           'NSNitroNserrPiInvalidUnset',
           'NSNitroNserrEmptyString',
           'NSNitroNserrInvalBtwArgs',
           'NSNitroNserrInvalArgSpecified',
           'NSNitroNserrInvalArgCspl',
           'NSNitroNserrFlowtypeNotApplicable',
           'NSNitroNserrInvalArgSpecifiedCs',
           'NSNitroNserrInvalGotoexprCs',
           'NSNitroNserrRebindFailed',
           'NSNitroNserrSecondBind',
           'NSNitroNserrNonhttpVs',
           'NSNitroNserrInvalXpathExpr',
           'NSNitroNserrXpathExprNotSupported',
           'NSNitroNserrTargetInval',
           'NSNitroNserrNonRespHttpVsList',
           'NSNitroNserrInvalVserverBind',
           'NSNitroNserrAppFreedNsb',
           'NSNitroNserrMultBindInval',
           'NSNitroNserrInvalidKeyvalue',
           'NSNitroNserrAsNostarturl',
           'NSNitroNserrAsExistStarturl',
           'NSNitroNserrAsNodenyurl',
           'NSNitroNserrAsExistDenyurl',
           'NSNitroNserrAsNocookieconsistency',
           'NSNitroNserrAsExistCookieconsistency',
           'NSNitroNserrAsNofieldconsistency',
           'NSNitroNserrAsExistFieldconsistency',
           'NSNitroNserrAsNoxss',
           'NSNitroNserrAsExistXss',
           'NSNitroNserrAsNosql',
           'NSNitroNserrAsExistSql',
           'NSNitroNserrAsNofieldformat',
           'NSNitroNserrAsExistFieldformat',
           'NSNitroNserrAsNoobjectexpression',
           'NSNitroNserrAsExistObjectexpression',
           'NSNitroNserrAsNofieldtype',
           'NSNitroNserrAsBadActionStarturl',
           'NSNitroNserrAsBadActionDenyurl',
           'NSNitroNserrAsBadActionCookieconsistency',
           'NSNitroNserrAsBadActionFieldconsistency',
           'NSNitroNserrAsBadActionXss',
           'NSNitroNserrAsBadActionSql',
           'NSNitroNserrAsBadActionFieldformat',
           'NSNitroNserrAsBadActionObjectexpression',
           'NSNitroNserrAsBadActionBufferoverflow',
           'NSNitroNserrAsBadActionCcard',
           'NSNitroNserrAsFieldformatMinGtMax',
           'NSNitroNserrAsFieldtypeBadNameLen',
           'NSNitroNserrAsBadCommentLen',
           'NSNitroNserrAsFieldtypeBadRegexLen',
           'NSNitroNserrAsSecurityCheckRequired',
           'NSNitroNserrAsFieldtypeBuiltin',
           'NSNitroNserrAsMaxEntities',
           'NSNitroNserrAsBadDefaultCharset',
           'NSNitroNserrAsBadCookieconsistencyName',
           'NSNitroNserrAsBadErrorurl',
           'NSNitroNserrAsBadEncodingUrl',
           'NSNitroNserrAsBadEncodingFieldname',
           'NSNitroNserrAsBadEncodingCookiename',
           'NSNitroNserrAsBadEncodingObjectexpressionName',
           'NSNitroNserrAsBadEncodingExpression',
           'NSNitroNserrAsBadEncodingRegex',
           'NSNitroNserrAsModifiedUrl',
           'NSNitroNserrAsModifiedObjectexpression',
           'NSNitroNserrAsCffieldBadFieldnameLen',
           'NSNitroNserrAsCffieldBadUrlLen',
           'NSNitroNserrAsNocffield',
           'NSNitroNserrAsBadCffName',
           'NSNitroNserrAsBadCffUrl',
           'NSNitroNserrAsCffDup',
           'NSNitroNserrAsBadActionXdos',
           'NSNitroNserrAsExistXmlDosUrl',
           'NSNitroNserrXmlUrlNotSupported',
           'NSNitroNserrAsNoXdosUrl',
           'NSNitroNserrAsInvalidXmlDosConf',
           'NSNitroNserrAsBadActionXmlSqlinjection',
           'NSNitroNserrAsBadActionXmlXss',
           'NSNitroNserrAsBadActionXmlWellformedness',
           'NSNitroNserrAsBadActionProfileType',
           'NSNitroNserrAsModifiedFieldname',
           'NSNitroNserrAsBadActionWsi',
           'NSNitroNserrAsExistXmlWsiUrl',
           'NSNitroNserrAsNoWsiUrl',
           'NSNitroNserrAsInvalidXmlWsiConf',
           'NSNitroNserrAsObjectnameTooBig',
           'NSNitroNserrAsObjectNoExist',
           'NSNitroNserrAsServerNameTooBig',
           'NSNitroNserrAsObjectNotReadable',
           'NSNitroNserrAsNoprofile',
           'NSNitroNserrAsBadActionXmlAttachment',
           'NSNitroNserrAsBadActionMsgval',
           'NSNitroNserrAsExistXmlMsgvalUrl',
           'NSNitroNserrAsNoMsgvalUrl',
           'NSNitroNserrAsInvalidXmlMsgvalConf',
           'NSNitroNserrAsBindXmlMsgvalConf',
           'NSNitroNserrAsImportFailed',
           'NSNitroNserrAsObjectExist',
           'NSNitroNserrAsInvalidOption',
           'NSNitroNserrAsRemoveFailed',
           'NSNitroNserrAsNoResource',
           'NSNitroNserrAsShowFailed',
           'NSNitroNserrAsDependencyFailed',
           'NSNitroNserrAsCompilationFailed',
           'NSNitroNserrInvalidObjectName',
           'NSNitroNserrAsImportDownloadFailed',
           'NSNitroNserrAsResourceInuse',
           'NSNitroNserrAsBadMappingData',
           'NSNitroNserrAsProfileChangeHtml',
           'NSNitroNserrAsProfileChangeXml',
           'NSNitroNserrAsImportAlreadyInprocess',
           'NSNitroNserrAsInvalidXmlErrorObject',
           'NSNitroNserrAsXmlWellformednessDisabled',
           'NSNitroNserrAsIndividualImportLimitExceeded',
           'NSNitroNserrAsTotalImportLimitExceeded',
           'NSNitroNserrAsLearningBusy',
           'NSNitroNserrAsDeprecatedXmlWsiRuleR4003',
           'NSNitroNserrAsExistXmlAttachmentUrl',
           'NSNitroNserrAsNoXmlAttachmentUrl',
           'NSNitroNserrAsBadActionSoapFault',
           'NSNitroNserrAsXmlDosValueOutOfRange',
           'NSNitroNserrAsXmlMsgvalCliError',
           'NSNitroNserrAsInvalidCustomSettingsObject',
           'NSNitroNserrAsSessionTimeoutLifetimeConflict',
           'NSNitroNserrAsClassicPolicyAlreadyBound',
           'NSNitroNserrAsAdvancedPolicyAlreadyBound',
           'NSNitroNserrAsCustomSettingsNoInjectionType',
           'NSNitroNserrAsNocsrfTag',
           'NSNitroNserrAsExistCsrfTag',
           'NSNitroNserrAsBadActionCsrfTag',
           'NSNitroNserrAsTurningTaggingOffCsrfTagOn',
           'NSNitroNserrAsTurningCsrfTagOnTaggingOff',
           'NSNitroNserrAsImportLimitLessThanImportDirSize',
           'NSNitroNserrAsUnsupportedImportProtocol',
           'NSNitroNserrAsUnsupportedExportProtocol',
           'NSNitroNserrAsExportFailed',
           'NSNitroNserrAsBadLocalFile',
           'NSNitroNserrAsInvalidRegexCustomObject',
           'NSNitroNserrAsBuiltinInvalidOp',
           'NSNitroNserrAsInvalidAdvPolicyState',
           'NSNitroNserrAsBuiltinNamesInConf',
           'NSNitroNserrAsDefaultProfileIsBypass',
           'NSNitroNserrAsNoLearnDenyurl',
           'NSNitroNserrAsNoLearnCsrfTag',
           'NSNitroNserrAsNoLearnCcard',
           'NSNitroNserrAsNoLearnBufferoverflow',
           'NSNitroNserrAsNoLearnXmlFormat',
           'NSNitroNserrAsNoLearnXmlSqlinjection',
           'NSNitroNserrAsNoLearnXmlXss',
           'NSNitroNserrAsNoLearnXmlMsgval',
           'NSNitroNserrAsNoLearnXmlSoapFault',
           'NSNitroNserrAsImportInternalError',
           'NSNitroNserrAsNetsvcConnFailed',
           'NSNitroNserrAsValidationFailed',
           'NSNitroNserrAsCkiTransformDisabled',
           'NSNitroNserrAsNoxmlxss',
           'NSNitroNserrAsExistXmlxss',
           'NSNitroNserrAsNoxmlsql',
           'NSNitroNserrAsExistXmlsql',
           'NSNitroNserrAsNoEndtag',
           'NSNitroNserrAsSigInvalidRuleid',
           'NSNitroNserrAsSigInvalidRuleVersion',
           'NSNitroNserrAsSigParseError',
           'NSNitroNserrAsSigInvalidAttribute',
           'NSNitroNserrAsSigMultipleLocations',
           'NSNitroNserrAsSigInvalidState',
           'NSNitroNserrAsCkiEncryptMethodIsNone',
           'NSNitroNserrAsUpdateFailed',
           'NSNitroNserrAsObjectNotUsed',
           'NSNitroNserrAsSigMultipleUrls',
           'NSNitroNserrAsSigMultipleFieldNames',
           'NSNitroNserrAsSqlinjectionKeywordInvalidAttribute',
           'NSNitroNserrAsSplstringInvalidAttribute',
           'NSNitroNserrAsSqlinjectionKeywordLiteralExceedMaxlen',
           'NSNitroNserrAsSplstringLiteralExceedMaxlen',
           'NSNitroNserrAsXssDeniedPatternInvalidAttribute',
           'NSNitroNserrAsXssDeniedPatternExceedMaxlen',
           'NSNitroNserrAsXssAllowedPatternInvalidAttribute',
           'NSNitroNserrAsXssAllowedPatternExceedMaxlen',
           'NSNitroNserrAsSigInternalError',
           'NSNitroNserrAsSigNonLiteralFastmatch',
           'NSNitroNserrAsSigNegatedLiteralFastmatch',
           'NSNitroNserrAsSigMemAllocFailed',
           'NSNitroNserrAsSigTooManyPatterns',
           'NSNitroNserrAsSigLiteralHexParseError',
           'NSNitroNserrAsSigPcreCompileError',
           'NSNitroNserrAsSigInvalidFileVersion',
           'NSNitroNserrNoSuchProfile',
           'NSNitroNserrProfileInUse',
           'NSNitroNserrInterfaceBound',
           'NSNitroNserrVridInterfaceNotBound',
           'NSNitroNserrNoSuchInterface',
           'NSNitroNserrInvalthreshold',
           'NSNitroNserrWrongthresholds',
           'NSNitroNserrInvalidSrcip',
           'NSNitroNserrThresholdUnsettable',
           'NSNitroNserrTimeUnsettable',
           'NSNitroNserrWrongLowThresholds',
           'NSNitroNserrPublicip',
           'NSNitroNserrPrivateip',
           'NSNitroNserrProxyip',
           'NSNitroNserrWildcardtcpvip',
           'NSNitroNserrWildcardanyvip',
           'NSNitroNserrFtpvippresent',
           'NSNitroNserrV46Usip',
           'NSNitroNserrIncompatibleIp',
           'NSNitroNserrTnlNetbridged',
           'NSNitroNserrTnlGre',
           'NSNitroNserrTnlRipmask',
           'NSNitroNserrVlanNetbridged',
           'NSNitroNserrMaxNetbridgeTunnel',
           'NSNitroNserrTunBound',
           'NSNitroNserrSubnetBound',
           'NSNitroNserrAppflowInvalidport',
           'NSNitroNserrIpfixMaxCollectors',
           'NSNitroNserrNoSuchCollector',
           'NSNitroNserrAppflowNcoreOnly',
           'NSNitroNserrAppflowNonzeroActionRefcount',
           'NSNitroNserrAppflowCollectorNameInuse',
           'NSNitroNserrAppflowActInval',
           'NSNitroNserr1gsfpspeedlimit',
           'NSNitroNserr1gsfpduplexlimit',
           'NSNitroNserr1gspeedlimit',
           'NSNitroNserr1gduplexlimit',
           'NSNitroNserr10gspeedlimit',
           'NSNitroNserr10gduplexlimit',
           'NSNitroNserr10gautoneglimit',
           'NSNitroNserr10gspeedonly',
           'NSNitroNserrFullduplexonly',
          ]
